@@ -17,7 +17,6 @@
 package org.gradle.caching.internal.controller;
 
 import com.google.common.annotations.VisibleForTesting;
-import org.apache.commons.io.IOUtils;
 import org.gradle.api.Action;
 import org.gradle.api.GradleException;
 import org.gradle.api.UncheckedIOException;
@@ -51,7 +50,6 @@ import org.gradle.internal.operations.RunnableBuildOperation;
 import javax.annotation.Nullable;
 import java.io.File;
 import java.io.FileInputStream;
-import java.io.FileNotFoundException;
 import java.io.FileOutputStream;
 import java.io.IOException;
 import java.io.InputStream;
@@ -177,21 +175,11 @@ public class DefaultBuildCacheController implements BuildCacheController {
             buildOperationExecutor.run(new RunnableBuildOperation() {
                 @Override
                 public void run(BuildOperationContext context) {
-                    InputStream input;
-                    try {
-                        input = new FileInputStream(file);
-                    } catch (FileNotFoundException e) {
-                        throw new UncheckedIOException(e);
-                    }
-
-                    try {
+                    try (InputStream input = new FileInputStream(file)) {
                         result = command.load(input);
                     } catch (IOException e) {
                         throw new UncheckedIOException(e);
-                    } finally {
-                        IOUtils.closeQuietly(input);
                     }
-
                     context.setResult(new UnpackOperationResult(
                         result.getArtifactEntryCount()
                     ));
