@@ -19,13 +19,14 @@ package org.gradle.api.plugins.buildcomparison.gradle;
 import org.gradle.api.Action;
 import org.gradle.api.DefaultTask;
 import org.gradle.api.GradleException;
-import org.gradle.api.Incubating;
 import org.gradle.api.Task;
 import org.gradle.api.logging.Logger;
+import org.gradle.api.model.ObjectFactory;
 import org.gradle.api.plugins.buildcomparison.compare.internal.BuildComparisonResult;
 import org.gradle.api.plugins.buildcomparison.gradle.internal.ComparableGradleBuildExecuter;
 import org.gradle.api.plugins.buildcomparison.gradle.internal.DefaultGradleBuildInvocationSpec;
 import org.gradle.api.plugins.buildcomparison.gradle.internal.GradleBuildComparison;
+import org.gradle.api.plugins.buildcomparison.gradle.internal.MovableFileStore;
 import org.gradle.api.plugins.buildcomparison.outcome.internal.archive.GeneratedArchiveBuildOutcome;
 import org.gradle.api.plugins.buildcomparison.outcome.internal.archive.GeneratedArchiveBuildOutcomeComparator;
 import org.gradle.api.plugins.buildcomparison.outcome.internal.archive.GeneratedArchiveBuildOutcomeComparisonResultHtmlRenderer;
@@ -35,7 +36,6 @@ import org.gradle.api.plugins.buildcomparison.outcome.internal.unknown.UnknownBu
 import org.gradle.api.plugins.buildcomparison.outcome.internal.unknown.UnknownBuildOutcomeComparisonResultHtmlRenderer;
 import org.gradle.api.plugins.buildcomparison.outcome.internal.unknown.UnknownBuildOutcomeHtmlRenderer;
 import org.gradle.api.specs.Spec;
-import org.gradle.api.tasks.Input;
 import org.gradle.api.tasks.Nested;
 import org.gradle.api.tasks.OutputDirectory;
 import org.gradle.api.tasks.TaskAction;
@@ -44,9 +44,11 @@ import org.gradle.internal.file.PathToFileResolver;
 import org.gradle.internal.logging.ConsoleRenderer;
 import org.gradle.internal.logging.progress.ProgressLogger;
 import org.gradle.internal.logging.progress.ProgressLoggerFactory;
-import org.gradle.internal.reflect.Instantiator;
 import org.gradle.internal.resource.local.FileStore;
+import org.gradle.internal.resource.local.FileStoreException;
+import org.gradle.internal.resource.local.LocallyAvailableResource;
 import org.gradle.internal.resource.local.PathNormalisingKeyFileStore;
+import org.gradle.util.GFileUtils;
 import org.gradle.util.GradleVersion;
 
 import javax.inject.Inject;
@@ -63,7 +65,6 @@ import java.util.Map;
  *
  * Please see the “Comparing Builds” chapter of the Gradle User Guide for more information.
  */
-@Incubating
 public class CompareGradleBuilds extends DefaultTask implements VerificationTask {
 
     public static final List<String> DEFAULT_TASKS = Arrays.asList("clean", "assemble");
@@ -77,10 +78,10 @@ public class CompareGradleBuilds extends DefaultTask implements VerificationTask
 
     public CompareGradleBuilds() {
         PathToFileResolver fileResolver = getFileResolver();
-        Instantiator instantiator = getInstantiator();
-        sourceBuild = instantiator.newInstance(DefaultGradleBuildInvocationSpec.class, fileResolver, getProject().getRootDir());
+        ObjectFactory objectFactory = getObjectFactory();
+        sourceBuild = objectFactory.newInstance(DefaultGradleBuildInvocationSpec.class, fileResolver, getProject().getRootDir());
         sourceBuild.setTasks(DEFAULT_TASKS);
-        targetBuild = instantiator.newInstance(DefaultGradleBuildInvocationSpec.class, fileResolver, getProject().getRootDir());
+        targetBuild = objectFactory.newInstance(DefaultGradleBuildInvocationSpec.class, fileResolver, getProject().getRootDir());
         targetBuild.setTasks(DEFAULT_TASKS);
 
         // Never up to date
@@ -101,8 +102,13 @@ public class CompareGradleBuilds extends DefaultTask implements VerificationTask
         throw new UnsupportedOperationException();
     }
 
+    /**
+     * Injects and returns an instance of {@link ObjectFactory}.
+     *
+     * @since 4.2
+     */
     @Inject
-    protected Instantiator getInstantiator() {
+    protected ObjectFactory getObjectFactory() {
         throw new UnsupportedOperationException();
     }
 
@@ -175,7 +181,6 @@ public class CompareGradleBuilds extends DefaultTask implements VerificationTask
      *
      * @return True if a comparison between non identical builds will fail the task execution, otherwise false.
      */
-    @Input
     public boolean getIgnoreFailures() {
         return ignoreFailures;
     }
@@ -240,7 +245,6 @@ public class CompareGradleBuilds extends DefaultTask implements VerificationTask
         Logger logger = getLogger();
         ProgressLogger progressLogger = getProgressLoggerFactory().newOperation(getClass());
         progressLogger.setDescription("Gradle Build Comparison");
-        progressLogger.setShortDescription(getName());
 
         GradleBuildComparison comparison = new GradleBuildComparison(
                 sourceBuildExecuter, targetBuildExecuter,
@@ -263,7 +267,7 @@ public class CompareGradleBuilds extends DefaultTask implements VerificationTask
         );
 
         File fileStoreTmpBase = getFileResolver().resolve(String.format(TMP_FILESTORAGE_PREFIX + "-%s-%s", getName(), System.currentTimeMillis()));
-        FileStore<String> fileStore = new PathNormalisingKeyFileStore(fileStoreTmpBase);
+        MovableFileStore<String> fileStore = new Files(fileStoreTmpBase);
 
         Map<String, String> hostAttributes = new LinkedHashMap<String, String>(4);
         hostAttributes.put("Project", getProject().getRootDir().getAbsolutePath());
@@ -290,4 +294,30 @@ public class CompareGradleBuilds extends DefaultTask implements VerificationTask
         }
     }
 
+    private static class Files implements MovableFileStore<String> {
+        private final File baseDir;
+        private final FileStore<String> delegate;
+
+        public Files(File baseDir) {
+            this.baseDir = baseDir;
+            this.delegate = new PathNormalisingKeyFileStore(baseDir);
+        }
+
+        @Override
+        public void moveFileStore(File destination) {
+            if (baseDir.isDirectory()) {
+                GFileUtils.moveDirectory(baseDir, destination);
+            }
+        }
+
+        @Override
+        public LocallyAvailableResource move(String key, File source) throws FileStoreException {
+            return delegate.move(key, source);
+        }
+
+        @Override
+        public LocallyAvailableResource add(String key, Action<File> addAction) throws FileStoreException {
+            return delegate.add(key, addAction);
+        }
+    }
 }
