@@ -16,8 +16,10 @@
 
 package org.gradle.api.plugins.quality;
 
+import org.gradle.api.reporting.CustomizableHtmlReport;
 import org.gradle.api.reporting.ReportContainer;
 import org.gradle.api.reporting.SingleFileReport;
+import org.gradle.api.tasks.Internal;
 
 /**
  * The reporting configuration for the {@link Checkstyle} task.
@@ -34,7 +36,8 @@ public interface CheckstyleReports extends ReportContainer<SingleFileReport> {
      * @return The checkstyle HTML report
      * @since 2.10
      */
-    SingleFileReport getHtml();
+    @Internal
+    CustomizableHtmlReport getHtml();
 
     /**
      * The checkstyle XML report
@@ -43,5 +46,6 @@ public interface CheckstyleReports extends ReportContainer<SingleFileReport> {
      *
      * @return The checkstyle XML report
      */
+    @Internal
     SingleFileReport getXml();
 }
