@@ -18,8 +18,11 @@ package org.gradle.api.internal.changedetection.rules;
 
 import com.google.common.collect.ImmutableList;
 import org.gradle.api.internal.TaskInternal;
-import org.gradle.api.internal.changedetection.state.ImplementationSnapshot;
 import org.gradle.api.internal.changedetection.state.TaskExecution;
+import org.gradle.internal.changes.TaskStateChangeVisitor;
+import org.gradle.internal.snapshot.impl.ImplementationSnapshot;
+
+import javax.annotation.Nullable;
 
 class TaskTypeTaskStateChanges implements TaskStateChanges {
     private final TaskExecution previousExecution;
@@ -40,22 +43,24 @@ class TaskTypeTaskStateChanges implements TaskStateChanges {
             return visitor.visitChange(new DescriptiveChange("Task '%s' has changed type from '%s' to '%s'.",
                 task.getIdentityPath(), prevImplementation.getTypeName(), taskImplementation.getTypeName()));
         }
-        if (taskImplementation.hasUnknownClassLoader()) {
-            return visitor.visitChange(new DescriptiveChange("Task '%s' was loaded with an unknown classloader", task.getIdentityPath()));
+        if (taskImplementation.isUnknown()) {
+            return visitor.visitChange(new DescriptiveChange("Task '%s' %s", task.getIdentityPath(), taskImplementation.getUnknownReason()));
         }
-        if (prevImplementation.hasUnknownClassLoader()) {
-            return visitor.visitChange(new DescriptiveChange("Task '%s' was loaded with an unknown classloader during the previous execution", task.getIdentityPath()));
+        if (prevImplementation.isUnknown()) {
+            return visitor.visitChange(new DescriptiveChange("During the previous execution of the task '%s', it %s", task.getIdentityPath(), prevImplementation.getUnknownReason()));
         }
         if (!taskImplementation.getClassLoaderHash().equals(prevImplementation.getClassLoaderHash())) {
             return visitor.visitChange(new DescriptiveChange("Task '%s' class path has changed from %s to %s.", task.getIdentityPath(), prevImplementation.getClassLoaderHash(), taskImplementation.getClassLoaderHash()));
         }
 
         ImmutableList<ImplementationSnapshot> taskActionImplementations = currentExecution.getTaskActionImplementations();
-        if (hasAnyUnknownClassLoader(taskActionImplementations)) {
-            return visitor.visitChange(new DescriptiveChange("Task '%s' has an additional action that was loaded with an unknown classloader", task.getIdentityPath()));
+        ImplementationSnapshot unknownImplementation = findUnknownImplementation(taskActionImplementations);
+        if (unknownImplementation != null) {
+            return visitor.visitChange(new DescriptiveChange("Task '%s' has an additional action that %s", task.getIdentityPath(), unknownImplementation.getUnknownReason()));
         }
-        if (hasAnyUnknownClassLoader(previousExecution.getTaskActionImplementations())) {
-            return visitor.visitChange(new DescriptiveChange("Task '%s' had an additional action that was loaded with an unknown classloader during the previous execution", task.getIdentityPath()));
+        ImplementationSnapshot previousUnknownImplementation = findUnknownImplementation(previousExecution.getTaskActionImplementations());
+        if (previousUnknownImplementation != null) {
+            return visitor.visitChange(new DescriptiveChange("During the previous execution of the task '%s', it had an additional action that %s", task.getIdentityPath(), previousUnknownImplementation.getUnknownReason()));
         }
         if (!taskActionImplementations.equals(previousExecution.getTaskActionImplementations())) {
             return visitor.visitChange(new DescriptiveChange("Task '%s' has additional actions that have changed", task.getIdentityPath()));
@@ -63,12 +68,13 @@ class TaskTypeTaskStateChanges implements TaskStateChanges {
         return true;
     }
 
-    private static boolean hasAnyUnknownClassLoader(Iterable<ImplementationSnapshot> implementations) {
+    @Nullable
+    private static ImplementationSnapshot findUnknownImplementation(Iterable<ImplementationSnapshot> implementations) {
         for (ImplementationSnapshot implementation : implementations) {
-            if (implementation.hasUnknownClassLoader()) {
-                return true;
+            if (implementation.isUnknown()) {
+                return implementation;
             }
         }
-        return false;
+        return null;
     }
 }
