@@ -16,11 +16,11 @@
 
 package org.gradle.internal.operations.notify;
 
-import org.gradle.BuildAdapter;
 import org.gradle.BuildListener;
-import org.gradle.api.Action;
 import org.gradle.api.Project;
+import org.gradle.api.internal.InternalAction;
 import org.gradle.api.invocation.Gradle;
+import org.gradle.internal.InternalBuildAdapter;
 import org.gradle.internal.event.ListenerManager;
 import org.gradle.internal.operations.BuildOperationDescriptor;
 import org.gradle.internal.operations.BuildOperationListener;
@@ -37,7 +37,6 @@ import java.util.Map;
 import java.util.Queue;
 import java.util.concurrent.ConcurrentHashMap;
 import java.util.concurrent.ConcurrentLinkedQueue;
-import java.util.concurrent.atomic.AtomicBoolean;
 import java.util.concurrent.locks.Lock;
 import java.util.concurrent.locks.ReentrantLock;
 
@@ -51,9 +50,9 @@ public class BuildOperationNotificationBridge {
     private class State {
         private ReplayAndAttachListener replayAndAttachListener = new ReplayAndAttachListener();
         private BuildOperationListener buildOperationListener = new Adapter(replayAndAttachListener);
-        private BuildOperationNotificationListener2 notificationListener;
+        private BuildOperationNotificationListener notificationListener;
 
-        private void assignSingleListener(BuildOperationNotificationListener2 notificationListener) {
+        private void assignSingleListener(BuildOperationNotificationListener notificationListener) {
             if (this.notificationListener != null) {
                 throw new IllegalStateException("listener is already registered (implementation class " + this.notificationListener.getClass().getName() + ")");
             }
@@ -92,13 +91,13 @@ public class BuildOperationNotificationBridge {
     // Listen for the end of configuration of the root project of the root build,
     // and discard buffered notifications if no listeners have yet appeared.
     // This avoids buffering until the end of the build when no listener comes.
-    private final BuildListener buildListener = new BuildAdapter() {
+    private final BuildListener buildListener = new InternalBuildAdapter() {
         public void buildStarted(@SuppressWarnings("NullableProblems") Gradle gradle) {
             if (gradle.getParent() == null) {
-                gradle.rootProject(new Action<Project>() {
+                gradle.rootProject(new InternalAction<Project>() {
                     @Override
                     public void execute(@SuppressWarnings("NullableProblems") Project project) {
-                        project.afterEvaluate(new Action<Project>() {
+                        project.afterEvaluate(new InternalAction<Project>() {
                             @Override
                             public void execute(@SuppressWarnings("NullableProblems") Project project) {
                                 State s = state;
@@ -114,29 +113,9 @@ public class BuildOperationNotificationBridge {
     };
 
     private final BuildOperationNotificationListenerRegistrar registrar = new BuildOperationNotificationListenerRegistrar() {
-        @Override
-        public void registerBuildScopeListener(BuildOperationNotificationListener notificationListener) {
-            State state = requireState();
-            BuildOperationNotificationListener2 adapted = adapt(notificationListener);
-            state.assignSingleListener(adapted);
-
-            // Remove the old adapter and start again.
-            // We explicitly do not want to receive finish notifications
-            // for any operations currently in flight,
-            // and we want to throw away the recorded notifications.
-            buildOperationListenerManager.removeListener(state.buildOperationListener);
-            state.buildOperationListener = new Adapter(adapted);
-            buildOperationListenerManager.addListener(state.buildOperationListener);
-            state.replayAndAttachListener = null;
-        }
 
         @Override
-        public void registerBuildScopeListenerAndReceiveStoredOperations(BuildOperationNotificationListener notificationListener) {
-            register(adapt(notificationListener));
-        }
-
-        @Override
-        public void register(BuildOperationNotificationListener2 listener) {
+        public void register(BuildOperationNotificationListener listener) {
             State state = requireState();
             state.assignSingleListener(listener);
             state.replayAndAttachListener.attach(listener);
@@ -175,12 +154,12 @@ public class BuildOperationNotificationBridge {
      */
     private static class Adapter implements BuildOperationListener {
 
-        private final BuildOperationNotificationListener2 notificationListener;
+        private final BuildOperationNotificationListener notificationListener;
 
         private final Map<Object, Object> parents = new ConcurrentHashMap<Object, Object>();
         private final Map<Object, Object> active = new ConcurrentHashMap<Object, Object>();
 
-        private Adapter(BuildOperationNotificationListener2 notificationListener) {
+        private Adapter(BuildOperationNotificationListener notificationListener) {
             this.notificationListener = notificationListener;
         }
 
@@ -265,7 +244,7 @@ public class BuildOperationNotificationBridge {
 
     }
 
-    private static class RecordingListener implements BuildOperationNotificationListener2 {
+    private static class RecordingListener implements BuildOperationNotificationListener {
 
         private final Queue<Object> storedEvents = new ConcurrentLinkedQueue<Object>();
 
@@ -286,16 +265,16 @@ public class BuildOperationNotificationBridge {
 
     }
 
-    private static class ReplayAndAttachListener implements BuildOperationNotificationListener2 {
+    private static class ReplayAndAttachListener implements BuildOperationNotificationListener {
 
         private RecordingListener recordingListener = new RecordingListener();
 
-        private volatile BuildOperationNotificationListener2 listener = recordingListener;
+        private volatile BuildOperationNotificationListener listener = recordingListener;
 
-        private final AtomicBoolean needLock = new AtomicBoolean(true);
+        private boolean needLock = true;
         private final Lock lock = new ReentrantLock();
 
-        private synchronized void attach(BuildOperationNotificationListener2 realListener) {
+        private void attach(BuildOperationNotificationListener realListener) {
             lock.lock();
             try {
                 for (Object storedEvent : recordingListener.storedEvents) {
@@ -312,13 +291,13 @@ public class BuildOperationNotificationBridge {
                 this.recordingListener = null; // release
             } finally {
                 lock.unlock();
-                needLock.set(false);
+                needLock = false;
             }
         }
 
         @Override
-        public synchronized void started(BuildOperationStartedNotification notification) {
-            if (needLock.get()) {
+        public void started(BuildOperationStartedNotification notification) {
+            if (needLock) {
                 lock.lock();
                 try {
                     listener.started(notification);
@@ -331,8 +310,8 @@ public class BuildOperationNotificationBridge {
         }
 
         @Override
-        public synchronized void progress(BuildOperationProgressNotification notification) {
-            if (needLock.get()) {
+        public void progress(BuildOperationProgressNotification notification) {
+            if (needLock) {
                 lock.lock();
                 try {
                     listener.progress(notification);
@@ -345,8 +324,8 @@ public class BuildOperationNotificationBridge {
         }
 
         @Override
-        public synchronized void finished(BuildOperationFinishedNotification notification) {
-            if (needLock.get()) {
+        public void finished(BuildOperationFinishedNotification notification) {
+            if (needLock) {
                 lock.lock();
                 try {
                     listener.finished(notification);
@@ -418,7 +397,7 @@ public class BuildOperationNotificationBridge {
         private final long timestamp;
         private final Object details;
 
-        public Progress(Object id, long timestamp, Object details) {
+        Progress(Object id, long timestamp, Object details) {
             this.id = id;
             this.timestamp = timestamp;
             this.details = details;
@@ -504,22 +483,4 @@ public class BuildOperationNotificationBridge {
         }
     }
 
-    private static BuildOperationNotificationListener2 adapt(final BuildOperationNotificationListener listener) {
-        return new BuildOperationNotificationListener2() {
-            @Override
-            public void started(BuildOperationStartedNotification notification) {
-                listener.started(notification);
-            }
-
-            @Override
-            public void progress(BuildOperationProgressNotification notification) {
-
-            }
-
-            @Override
-            public void finished(BuildOperationFinishedNotification notification) {
-                listener.finished(notification);
-            }
-        };
-    }
 }
