@@ -16,10 +16,12 @@
 
 package org.gradle.api.internal.artifacts;
 
-import org.gradle.api.internal.artifacts.transform.DefaultTransformInfoFactory;
-import org.gradle.api.internal.artifacts.transform.TransformInfoDependencyResolver;
-import org.gradle.api.internal.artifacts.transform.TransformInfoExecutor;
-import org.gradle.api.internal.artifacts.transform.TransformInfoFactory;
+import org.gradle.api.internal.artifacts.transform.ArtifactTransformListener;
+import org.gradle.api.internal.artifacts.transform.DefaultTransformNodeFactory;
+import org.gradle.api.internal.artifacts.transform.TransformNodeDependencyResolver;
+import org.gradle.api.internal.artifacts.transform.TransformNodeExecutor;
+import org.gradle.api.internal.artifacts.transform.TransformNodeFactory;
+import org.gradle.internal.event.ListenerManager;
 import org.gradle.internal.operations.BuildOperationExecutor;
 import org.gradle.internal.service.ServiceRegistration;
 import org.gradle.internal.service.scopes.AbstractPluginServiceRegistry;
@@ -34,11 +36,6 @@ public class DependencyServices extends AbstractPluginServiceRegistry {
         registration.addProvider(new DependencyManagementGradleUserHomeScopeServices());
     }
 
-    @Override
-    public void registerBuildSessionServices(ServiceRegistration registration) {
-        registration.addProvider(new DependencyManagementBuildSessionServices());
-    }
-
     @Override
     public void registerBuildServices(ServiceRegistration registration) {
         registration.addProvider(new DependencyManagementBuildScopeServices());
@@ -49,17 +46,26 @@ public class DependencyServices extends AbstractPluginServiceRegistry {
         registration.addProvider(new DependencyManagementBuildTreeScopeServices());
     }
 
-    private static class DependencyManagementBuildSessionServices {
-        TransformInfoFactory createTransformInfoFactory() {
-            return new DefaultTransformInfoFactory();
+    @Override
+    public void registerGradleServices(ServiceRegistration registration) {
+        registration.addProvider(new DependencyManagementGradleServices());
+    }
+
+    private static class DependencyManagementGradleServices {
+        ArtifactTransformListener createArtifactTransformListener(ListenerManager listenerManager) {
+            return listenerManager.getBroadcaster(ArtifactTransformListener.class);
         }
 
-        TransformInfoDependencyResolver createTransformInfoResolver(TransformInfoFactory transformInfoFactory) {
-            return new TransformInfoDependencyResolver(transformInfoFactory);
+        TransformNodeFactory createTransformNodeFactory() {
+            return new DefaultTransformNodeFactory();
         }
 
-        TransformInfoExecutor createTransformInfoExecutor(BuildOperationExecutor buildOperationExecutor) {
-            return new TransformInfoExecutor(buildOperationExecutor);
+        TransformNodeDependencyResolver createTransformNodeDepndencyResolver(TransformNodeFactory transformNodeFactory) {
+            return new TransformNodeDependencyResolver(transformNodeFactory);
+        }
+
+        TransformNodeExecutor createTransformNodeExecutor(BuildOperationExecutor buildOperationExecutor, ArtifactTransformListener transformListener) {
+            return new TransformNodeExecutor(buildOperationExecutor, transformListener);
         }
     }
 }
