@@ -25,6 +25,7 @@ import org.gradle.api.artifacts.ComponentMetadataContext;
 import org.gradle.api.artifacts.ComponentMetadataDetails;
 import org.gradle.api.artifacts.ModuleVersionIdentifier;
 import org.gradle.api.artifacts.VariantMetadata;
+import org.gradle.api.artifacts.component.ComponentIdentifier;
 import org.gradle.api.artifacts.ivy.IvyModuleDescriptor;
 import org.gradle.api.attributes.AttributeContainer;
 import org.gradle.api.internal.artifacts.ComponentMetadataProcessor;
@@ -37,54 +38,116 @@ import org.gradle.api.internal.artifacts.repositories.resolver.DirectDependencyM
 import org.gradle.api.internal.attributes.AttributeContainerInternal;
 import org.gradle.api.internal.attributes.ImmutableAttributesFactory;
 import org.gradle.api.internal.project.ProjectInternal;
+import org.gradle.internal.Actions;
 import org.gradle.internal.action.ConfigurableRule;
 import org.gradle.internal.action.DefaultConfigurableRules;
 import org.gradle.internal.action.InstantiatingAction;
-import org.gradle.internal.component.external.model.IvyModuleResolveMetadata;
 import org.gradle.internal.component.external.model.ModuleComponentResolveMetadata;
 import org.gradle.internal.component.external.model.MutableModuleComponentResolveMetadata;
+import org.gradle.internal.component.external.model.ivy.DefaultIvyModuleResolveMetadata;
+import org.gradle.internal.component.external.model.ivy.IvyModuleResolveMetadata;
+import org.gradle.internal.component.external.model.ivy.RealisedIvyModuleResolveMetadata;
+import org.gradle.internal.component.external.model.maven.DefaultMavenModuleResolveMetadata;
+import org.gradle.internal.component.external.model.maven.RealisedMavenModuleResolveMetadata;
 import org.gradle.internal.reflect.Instantiator;
 import org.gradle.internal.resolve.ModuleVersionResolveException;
 import org.gradle.internal.resolve.caching.ComponentMetadataRuleExecutor;
 import org.gradle.internal.rules.RuleAction;
 import org.gradle.internal.rules.SpecRuleAction;
+import org.gradle.internal.serialize.InputStreamBackedDecoder;
+import org.gradle.internal.serialize.OutputStreamBackedEncoder;
+import org.gradle.internal.serialize.Serializer;
 import org.gradle.internal.typeconversion.NotationParser;
 
+import java.io.ByteArrayInputStream;
+import java.io.ByteArrayOutputStream;
+import java.io.IOException;
 import java.util.ArrayList;
+import java.util.Collection;
 import java.util.List;
-import java.util.Set;
+
+import static org.gradle.api.internal.artifacts.repositories.resolver.VirtualComponentHelper.makeVirtual;
 
 public class DefaultComponentMetadataProcessor implements ComponentMetadataProcessor {
 
+    private final static boolean FORCE_REALIZE = Boolean.getBoolean("org.gradle.integtest.force.realize.metadata");
+
     private static final Transformer<ModuleComponentResolveMetadata, WrappingComponentMetadataContext> DETAILS_TO_RESULT = new Transformer<ModuleComponentResolveMetadata, WrappingComponentMetadataContext>() {
-            @Override
-            public ModuleComponentResolveMetadata transform(WrappingComponentMetadataContext componentMetadataContext) {
-                return componentMetadataContext.getMutableMetadata().asImmutable();
+        @Override
+        public ModuleComponentResolveMetadata transform(WrappingComponentMetadataContext componentMetadataContext) {
+            ModuleComponentResolveMetadata metadata = componentMetadataContext.getMutableMetadata().asImmutable();
+            return realizeMetadata(metadata);
+        }
+    };
+
+    private ModuleComponentResolveMetadata maybeForceRealisation(ModuleComponentResolveMetadata metadata) {
+        if (FORCE_REALIZE) {
+            metadata = realizeMetadata(metadata);
+            metadata = forceSerialization(metadata);
+        }
+        return metadata;
+    }
+
+    private static ModuleComponentResolveMetadata realizeMetadata(ModuleComponentResolveMetadata metadata) {
+        if (metadata instanceof DefaultIvyModuleResolveMetadata) {
+            metadata = RealisedIvyModuleResolveMetadata.transform((DefaultIvyModuleResolveMetadata) metadata);
+        } else if (metadata instanceof DefaultMavenModuleResolveMetadata) {
+            metadata = RealisedMavenModuleResolveMetadata.transform((DefaultMavenModuleResolveMetadata) metadata);
+        } else {
+            throw new IllegalStateException("Invalid type received: " + metadata.getClass());
+        }
+        return metadata;
+    }
+
+    private ModuleComponentResolveMetadata forceSerialization(ModuleComponentResolveMetadata metadata) {
+        Serializer<ModuleComponentResolveMetadata> serializer = ruleExecutor.getComponentMetadataContextSerializer();
+        ByteArrayOutputStream byteArrayOutputStream = new ByteArrayOutputStream();
+        byte[] bytes;
+        try {
+            serializer.write(new OutputStreamBackedEncoder(byteArrayOutputStream), metadata);
+            bytes = byteArrayOutputStream.toByteArray();
+        } catch (Exception e) {
+            throw new RuntimeException(e);
+        } finally {
+            try {
+                byteArrayOutputStream.close();
+            } catch (IOException e) {
+                throw new RuntimeException(e);
             }
-        };
+        }
+        try {
+            ModuleComponentResolveMetadata forceRead = serializer.read(new InputStreamBackedDecoder(new ByteArrayInputStream(bytes)));
+            // TODO: CC cannot enable this assertion because moduleSource is not serialized, so doesn't appear in the deserialized form
+            //assert metadata.equals(forceRead);
+            metadata = forceRead;
+        } catch (Exception e) {
+            throw new RuntimeException(e);
+        }
+        return metadata;
+    }
 
     private final Instantiator instantiator;
     private final NotationParser<Object, DirectDependencyMetadataImpl> dependencyMetadataNotationParser;
     private final NotationParser<Object, DependencyConstraintMetadataImpl> dependencyConstraintMetadataNotationParser;
+    private final NotationParser<Object, ComponentIdentifier> componentIdentifierNotationParser;
     private final ImmutableAttributesFactory attributesFactory;
     private final ComponentMetadataRuleExecutor ruleExecutor;
     private final MetadataResolutionContext metadataResolutionContext;
-    private final Set<SpecRuleAction<? super ComponentMetadataDetails>> rules;
-    private final Set<SpecConfigurableRule> classBasedRules;
+    private final ComponentMetadataRuleContainer metadataRuleContainer;
 
-    public DefaultComponentMetadataProcessor(Set<SpecRuleAction<? super ComponentMetadataDetails>> rules,
-                                             Set<SpecConfigurableRule> classBasedRules,
+    public DefaultComponentMetadataProcessor(ComponentMetadataRuleContainer metadataRuleContainer,
                                              Instantiator instantiator,
                                              NotationParser<Object, DirectDependencyMetadataImpl> dependencyMetadataNotationParser,
                                              NotationParser<Object, DependencyConstraintMetadataImpl> dependencyConstraintMetadataNotationParser,
+                                             NotationParser<Object, ComponentIdentifier> componentIdentifierNotationParser,
                                              ImmutableAttributesFactory attributesFactory,
                                              ComponentMetadataRuleExecutor ruleExecutor,
                                              MetadataResolutionContext resolutionContext) {
-        this.rules = rules;
-        this.classBasedRules = classBasedRules;
+        this.metadataRuleContainer = metadataRuleContainer;
         this.instantiator = instantiator;
         this.dependencyMetadataNotationParser = dependencyMetadataNotationParser;
         this.dependencyConstraintMetadataNotationParser = dependencyConstraintMetadataNotationParser;
+        this.componentIdentifierNotationParser = componentIdentifierNotationParser;
         this.attributesFactory = attributesFactory;
         this.ruleExecutor = ruleExecutor;
         this.metadataResolutionContext = resolutionContext;
@@ -92,16 +155,29 @@ public class DefaultComponentMetadataProcessor implements ComponentMetadataProce
 
     @Override
     public ModuleComponentResolveMetadata processMetadata(ModuleComponentResolveMetadata metadata) {
+        metadata.getVariantMetadataRules().setVariantDerivationStrategy(metadataRuleContainer.getVariantDerivationStrategy());
         ModuleComponentResolveMetadata updatedMetadata;
-        if (rules.isEmpty() && classBasedRules.isEmpty()) {
-            updatedMetadata = metadata;
-        } else if (rules.isEmpty()) {
-            updatedMetadata = processClassRuleWithCaching(metadata, metadataResolutionContext);
+        if (metadataRuleContainer.isEmpty()) {
+            updatedMetadata = maybeForceRealisation(metadata);
+        } else if (metadataRuleContainer.isClassBasedRulesOnly()) {
+            Action<ComponentMetadataContext> action = collectRulesAndCreateAction(metadataRuleContainer.getOnlyClassRules(), metadata.getModuleVersionId(), metadataResolutionContext.getInjectingInstantiator());
+            if (action instanceof InstantiatingAction) {
+                InstantiatingAction<ComponentMetadataContext> ia = (InstantiatingAction<ComponentMetadataContext>) action;
+                if (ia.getRules().isCacheable()) {
+                    updatedMetadata = processClassRuleWithCaching(ia, metadata, metadataResolutionContext);
+                } else {
+                    MutableModuleComponentResolveMetadata mutableMetadata = metadata.asMutable();
+                    processClassRule(action, metadata, createDetails(mutableMetadata));
+                    updatedMetadata = maybeForceRealisation(mutableMetadata.asImmutable());
+                }
+            } else {
+                updatedMetadata = maybeForceRealisation(metadata);
+            }
         } else {
             MutableModuleComponentResolveMetadata mutableMetadata = metadata.asMutable();
-            ComponentMetadataDetails details = instantiator.newInstance(ComponentMetadataDetailsAdapter.class, mutableMetadata, instantiator, dependencyMetadataNotationParser, dependencyConstraintMetadataNotationParser);
+            ComponentMetadataDetails details = createDetails(mutableMetadata);
             processAllRules(metadata, details, metadata.getModuleVersionId());
-            updatedMetadata = mutableMetadata.asImmutable();
+            updatedMetadata = maybeForceRealisation(mutableMetadata.asImmutable());
         }
 
         if (!updatedMetadata.getStatusScheme().contains(updatedMetadata.getStatus())) {
@@ -110,13 +186,17 @@ public class DefaultComponentMetadataProcessor implements ComponentMetadataProce
         return updatedMetadata;
     }
 
+    protected ComponentMetadataDetails createDetails(MutableModuleComponentResolveMetadata mutableMetadata) {
+        return instantiator.newInstance(ComponentMetadataDetailsAdapter.class, mutableMetadata, instantiator, dependencyMetadataNotationParser, dependencyConstraintMetadataNotationParser, componentIdentifierNotationParser);
+    }
+
     @Override
     public ComponentMetadata processMetadata(ComponentMetadata metadata) {
         ComponentMetadata updatedMetadata;
-        if (rules.isEmpty() && classBasedRules.isEmpty()) {
+        if (metadataRuleContainer.isEmpty()) {
             updatedMetadata = metadata;
         } else {
-            ShallowComponentMetadataAdapter details = new ShallowComponentMetadataAdapter(metadata, attributesFactory);
+            ShallowComponentMetadataAdapter details = new ShallowComponentMetadataAdapter(componentIdentifierNotationParser, metadata, attributesFactory);
             processAllRules(null, details, metadata.getId());
             updatedMetadata = details.asImmutable();
         }
@@ -127,15 +207,18 @@ public class DefaultComponentMetadataProcessor implements ComponentMetadataProce
     }
 
     private void processAllRules(ModuleComponentResolveMetadata metadata, ComponentMetadataDetails details, ModuleVersionIdentifier id) {
-        for (SpecRuleAction<? super ComponentMetadataDetails> rule : rules) {
-            processRule(rule, metadata, details);
+        for (MetadataRuleWrapper wrapper : metadataRuleContainer) {
+            if (wrapper.isClassBased()) {
+                Collection<SpecConfigurableRule> rules = wrapper.getClassRules();
+                Action<ComponentMetadataContext> action = collectRulesAndCreateAction(rules, id, instantiator);
+                processClassRule(action, metadata, details);
+            } else {
+                processRule(wrapper.getRule(), metadata, details);
+            }
         }
-        processClassRule(metadata, details, id, metadataResolutionContext.getInjectingInstantiator());
     }
 
-    private void processClassRule(final ModuleComponentResolveMetadata metadata, final ComponentMetadataDetails details, ModuleVersionIdentifier id, Instantiator instantiator) {
-        InstantiatingAction<ComponentMetadataContext> action = collectRulesAndCreateAction(id, instantiator);
-
+    private void processClassRule(Action<ComponentMetadataContext> action, final ModuleComponentResolveMetadata metadata, final ComponentMetadataDetails details) {
         DefaultComponentMetadataContext componentMetadataContext = new DefaultComponentMetadataContext(details, metadata);
         try {
             action.execute(componentMetadataContext);
@@ -146,14 +229,13 @@ public class DefaultComponentMetadataProcessor implements ComponentMetadataProce
         }
     }
 
-    private ModuleComponentResolveMetadata processClassRuleWithCaching(final ModuleComponentResolveMetadata metadata, MetadataResolutionContext metadataResolutionContext) {
-        InstantiatingAction<ComponentMetadataContext> action = collectRulesAndCreateAction(metadata.getModuleVersionId(), metadataResolutionContext.getInjectingInstantiator());
+    private ModuleComponentResolveMetadata processClassRuleWithCaching(InstantiatingAction<ComponentMetadataContext> action, final ModuleComponentResolveMetadata metadata, MetadataResolutionContext metadataResolutionContext) {
         try {
             return ruleExecutor.execute(metadata, action, DETAILS_TO_RESULT,
                 new Transformer<WrappingComponentMetadataContext, ModuleComponentResolveMetadata>() {
                     @Override
                     public WrappingComponentMetadataContext transform(ModuleComponentResolveMetadata moduleVersionIdentifier) {
-                        return new WrappingComponentMetadataContext(metadata, instantiator, dependencyMetadataNotationParser, dependencyConstraintMetadataNotationParser);
+                        return new WrappingComponentMetadataContext(metadata, instantiator, dependencyMetadataNotationParser, dependencyConstraintMetadataNotationParser, componentIdentifierNotationParser);
                     }
                 }, metadataResolutionContext.getCachePolicy());
         } catch (InvalidUserCodeException e) {
@@ -163,14 +245,17 @@ public class DefaultComponentMetadataProcessor implements ComponentMetadataProce
         }
     }
 
-    private InstantiatingAction<ComponentMetadataContext> collectRulesAndCreateAction(ModuleVersionIdentifier id, Instantiator instantiator) {
-        ArrayList<ConfigurableRule<ComponentMetadataContext>> rules = new ArrayList<ConfigurableRule<ComponentMetadataContext>>();
-        for (SpecConfigurableRule classBasedRule : classBasedRules) {
+    private Action<ComponentMetadataContext> collectRulesAndCreateAction(Collection<SpecConfigurableRule> rules, ModuleVersionIdentifier id, Instantiator instantiator) {
+        if (rules.isEmpty()) {
+            return Actions.doNothing();
+        }
+        ArrayList<ConfigurableRule<ComponentMetadataContext>> collectedRules = new ArrayList<ConfigurableRule<ComponentMetadataContext>>();
+        for (SpecConfigurableRule classBasedRule : rules) {
             if (classBasedRule.getSpec().isSatisfiedBy(id)) {
-                rules.add(classBasedRule.getConfigurableRule());
+                collectedRules.add(classBasedRule.getConfigurableRule());
             }
         }
-        return new InstantiatingAction<ComponentMetadataContext>(new DefaultConfigurableRules<ComponentMetadataContext>(rules), instantiator, new ExceptionHandler());
+        return new InstantiatingAction<ComponentMetadataContext>(new DefaultConfigurableRules<ComponentMetadataContext>(collectedRules), instantiator, new ExceptionHandler());
     }
 
 
@@ -217,16 +302,20 @@ public class DefaultComponentMetadataProcessor implements ComponentMetadataProce
     }
 
     static class ShallowComponentMetadataAdapter implements ComponentMetadataDetails {
+        private final NotationParser<Object, ComponentIdentifier> componentIdentifierNotationParser;
         private final ModuleVersionIdentifier id;
         private boolean changing;
         private List<String> statusScheme;
         private AttributeContainerInternal attributes;
+        private final List<ComponentIdentifier> owners;
 
-        public ShallowComponentMetadataAdapter(ComponentMetadata source, ImmutableAttributesFactory attributesFactory) {
+        public ShallowComponentMetadataAdapter(NotationParser<Object, ComponentIdentifier> componentIdentifierNotationParser, ComponentMetadata source, ImmutableAttributesFactory attributesFactory) {
+            this.componentIdentifierNotationParser = componentIdentifierNotationParser;
             id = source.getId();
             changing = source.isChanging();
             statusScheme = source.getStatusScheme();
             attributes = attributesFactory.mutable((AttributeContainerInternal) source.getAttributes());
+            owners = Lists.newArrayListWithExpectedSize(1);
         }
 
         @Override
@@ -254,6 +343,20 @@ public class DefaultComponentMetadataProcessor implements ComponentMetadataProce
 
         }
 
+        @Override
+        public void belongsTo(Object notation) {
+            belongsTo(notation, true);
+        }
+
+        @Override
+        public void belongsTo(Object notation, boolean virtual) {
+            ComponentIdentifier id = componentIdentifierNotationParser.parseNotation(notation);
+            if (virtual) {
+                id = makeVirtual(id);
+            }
+            owners.add(id);
+        }
+
         @Override
         public ModuleVersionIdentifier getId() {
             return id;
