@@ -153,11 +153,6 @@ public class ComponentState implements ComponentResolutionState, DependencyGraph
         return metadata;
     }
 
-    ComponentResolveMetadata getMetadataWithoutRetryMissing() {
-        resolve(false);
-        return metadata;
-    }
-
     @Override
     public ComponentIdentifier getComponentId() {
         // Use the resolved component id if available: this ensures that Maven Snapshot ids are correctly reported
@@ -193,10 +188,6 @@ public class ComponentState implements ComponentResolutionState, DependencyGraph
     }
 
     public void resolve() {
-        resolve(true);
-    }
-
-    public void resolve(boolean retryMissing) {
         if (alreadyResolved()) {
             return;
         }
@@ -204,7 +195,7 @@ public class ComponentState implements ComponentResolutionState, DependencyGraph
         // Any metadata overrides (e.g classifier/artifacts/client-module) will be taken from the first dependency that referenced this component
         ComponentOverrideMetadata componentOverrideMetadata = DefaultComponentOverrideMetadata.forDependency(firstSelectedBy.getDependencyMetadata());
 
-        DefaultBuildableComponentResolveResult result = new DefaultBuildableComponentResolveResult(retryMissing);
+        DefaultBuildableComponentResolveResult result = new DefaultBuildableComponentResolveResult();
         resolver.resolve(componentIdentifier, componentOverrideMetadata, result);
         if (result.getFailure() != null) {
             metadataResolveFailure = result.getFailure();
@@ -455,7 +446,7 @@ public class ComponentState implements ComponentResolutionState, DependencyGraph
                 if (!rejectedByThisSelector.isEmpty()) {
                     descriptor = descriptor.withReason(new RejectedBySelectorReason(rejectedByThisSelector, descriptor));
                 } else {
-                    rejectedByThisSelector = rejectedBySelectors.get(selectorState.getVersionConstraint().getPreferredSelector());
+                    rejectedByThisSelector = rejectedBySelectors.get(selectorState.getVersionConstraint().getRequiredSelector());
                     if (!rejectedByThisSelector.isEmpty()) {
                         descriptor = descriptor.withReason(new UnmatchedVersionsReason(rejectedByThisSelector, descriptor));
                     }
