@@ -20,6 +20,7 @@ import com.google.common.collect.Lists;
 import com.google.common.collect.Maps;
 import org.gradle.api.Action;
 import org.gradle.api.GradleException;
+import org.gradle.api.artifacts.Configuration;
 import org.gradle.api.artifacts.ModuleVersionIdentifier;
 import org.gradle.api.artifacts.component.ComponentIdentifier;
 import org.gradle.api.capabilities.Capability;
@@ -37,7 +38,6 @@ import org.gradle.api.internal.artifacts.ivyservice.resolveengine.graph.conflict
 import org.gradle.api.internal.artifacts.ivyservice.resolveengine.graph.conflicts.DefaultCapabilitiesConflictHandler;
 import org.gradle.api.internal.artifacts.ivyservice.resolveengine.graph.conflicts.ModuleConflictHandler;
 import org.gradle.api.internal.artifacts.ivyservice.resolveengine.graph.conflicts.PotentialConflict;
-import org.gradle.api.internal.artifacts.ivyservice.resolveengine.graph.selectors.SelectorStateResolver;
 import org.gradle.api.internal.attributes.AttributesSchemaInternal;
 import org.gradle.api.internal.attributes.ImmutableAttributesFactory;
 import org.gradle.api.specs.Spec;
@@ -61,6 +61,7 @@ import java.util.Collections;
 import java.util.Comparator;
 import java.util.List;
 import java.util.Map;
+import java.util.Set;
 
 public class DependencyGraphBuilder {
     private static final Logger LOGGER = LoggerFactory.getLogger(DependencyGraphBuilder.class);
@@ -121,9 +122,11 @@ public class DependencyGraphBuilder {
         DefaultBuildableComponentResolveResult rootModule = new DefaultBuildableComponentResolveResult();
         moduleResolver.resolve(resolveContext, rootModule);
 
-        final ResolveState resolveState = new ResolveState(idGenerator, rootModule, resolveContext.getName(), idResolver, metaDataResolver, edgeFilter, attributesSchema, moduleExclusions, moduleReplacementsData, componentSelectorConverter, attributesFactory, dependencySubstitutionApplicator, versionSelectorScheme, versionComparator, versionParser);
+        int graphSize = estimateSize(resolveContext);
+        final ResolveState resolveState = new ResolveState(idGenerator, rootModule, resolveContext.getName(), idResolver, metaDataResolver, edgeFilter, attributesSchema, moduleExclusions, moduleReplacementsData, componentSelectorConverter, attributesFactory, dependencySubstitutionApplicator, versionSelectorScheme, versionComparator, versionParser, moduleConflictHandler.getResolver(), graphSize);
 
-        traverseGraph(resolveState);
+        Map<ModuleVersionIdentifier, ComponentIdentifier> componentIdentifierCache = Maps.newHashMapWithExpectedSize(graphSize/2);
+        traverseGraph(resolveState, componentIdentifierCache);
 
         validateGraph(resolveState);
 
@@ -131,15 +134,25 @@ public class DependencyGraphBuilder {
 
     }
 
+    /**
+     * This method is a heuristic that gives an idea of the "size" of the graph. The larger
+     * the graph is, the higher the risk of internal resizes exists, so we try to estimate
+     * the size of the graph to avoid maps resizing.
+     */
+    private static int estimateSize(ResolveContext resolveContext) {
+        int estimate = 0;
+        if (resolveContext instanceof Configuration) {
+            estimate = (int) (512 * Math.log(((Configuration) resolveContext).getAllDependencies().size()));
+        }
+        return Math.max(10, estimate);
+    }
+
     /**
      * Traverses the dependency graph, resolving conflicts and building the paths from the root configuration.
      */
-    private void traverseGraph(final ResolveState resolveState) {
+    private void traverseGraph(final ResolveState resolveState, final Map<ModuleVersionIdentifier, ComponentIdentifier> componentIdentifierCache) {
         resolveState.onMoreSelected(resolveState.getRoot());
         final List<EdgeState> dependencies = Lists.newArrayList();
-        final Map<ModuleVersionIdentifier, ComponentIdentifier> componentIdentifierCache = Maps.newHashMap();
-
-        final PendingDependenciesHandler pendingDependenciesHandler = new DefaultPendingDependenciesHandler();
 
         while (resolveState.peek() != null || moduleConflictHandler.hasConflicts() || capabilitiesConflictHandler.hasConflicts()) {
             if (resolveState.peek() != null) {
@@ -151,7 +164,7 @@ public class DependencyGraphBuilder {
 
                 // Initialize and collect any new outgoing edges of this node
                 dependencies.clear();
-                node.visitOutgoingDependencies(dependencies, pendingDependenciesHandler);
+                node.visitOutgoingDependencies(dependencies);
                 resolveEdges(node, dependencies, resolveState, componentIdentifierCache);
             } else {
                 // We have some batched up conflicts. Resolve the first, and continue traversing the graph
@@ -226,10 +239,8 @@ public class DependencyGraphBuilder {
     private void performSelection(ResolveState resolveState, ModuleResolveState module) {
         ComponentState currentSelection = module.getSelected();
 
-        SelectorStateResolver<ComponentState> selectorStateResolver = new SelectorStateResolver<ComponentState>(moduleConflictHandler.getResolver(), resolveState, resolveState.getRoot().getComponent());
-        ComponentState selected;
         try {
-            selected = selectorStateResolver.selectBest(module.getId(), module.getSelectors());
+            module.maybeUpdateSelection();
         } catch (ModuleVersionResolveException e) {
             // Ignore: All selectors failed, and will have failures recorded
             return;
@@ -237,19 +248,9 @@ public class DependencyGraphBuilder {
 
         // If no current selection for module, just use the candidate.
         if (currentSelection == null) {
-            module.select(selected);
             // This is the first time we've seen the module, so register with conflict resolver.
             checkForModuleConflicts(resolveState, module);
-            return;
         }
-
-        // If current selection is still the best choice, then only need to point new edge/selector at current selection.
-        if (selected == currentSelection) {
-            return;
-        }
-
-        // New candidate is a preferred choice over current selection. Reset the module state and reselect.
-        module.changeSelection(selected);
     }
 
     private void checkForModuleConflicts(ResolveState resolveState, ModuleResolveState module) {
@@ -324,10 +325,28 @@ public class DependencyGraphBuilder {
                 // We need to attach failures on unattached dependencies too, in case a node wasn't selected
                 // at all, but we still want to see an error message for it.
                 attachFailureToEdges(error, module.getUnattachedDependencies());
+            } else if (module.isVirtualPlatform() && module.hasCompetingForceSelectors()) {
+                attachMultipleForceOnPlatformFailureToEdges(module);
             }
         }
     }
 
+    private void attachMultipleForceOnPlatformFailureToEdges(ModuleResolveState module) {
+        List<EdgeState> forcedEdges = Lists.newArrayList();
+        Set<ModuleResolveState> participatingModules = module.getPlatformState().getParticipatingModules();
+        for (ModuleResolveState participatingModule : participatingModules) {
+            for (EdgeState incomingEdge : participatingModule.getIncomingEdges()) {
+                if (incomingEdge.getSelector().isForce()) {
+                    // Filter out platform originating edges
+                    if (!incomingEdge.getFrom().getComponent().getModule().equals(module)) {
+                        forcedEdges.add(incomingEdge);
+                    }
+                }
+            }
+        }
+        attachFailureToEdges(new GradleException("Multiple forces on different versions for virtual platform " + module.getId()), forcedEdges);
+    }
+
     /**
      * Attaches errors late in the process. This is useful whenever we have built a graph, and that
      * validation is going to cause a failure (the error is not in the graph itself, but in the way
