@@ -165,9 +165,8 @@ class NodeState implements DependencyGraphNode {
      * The {@link #outgoingEdges} collection is populated, as is the `discoveredEdges` parameter.
      *
      * @param discoveredEdges A collector for visited edges.
-     * @param pendingDependenciesHandler Handler for pending dependencies.
      */
-    public void visitOutgoingDependencies(Collection<EdgeState> discoveredEdges, PendingDependenciesHandler pendingDependenciesHandler) {
+    public void visitOutgoingDependencies(Collection<EdgeState> discoveredEdges) {
         // If this configuration's version is in conflict, do not traverse.
         // If none of the incoming edges are transitive, remove previous state and do not traverse.
         // If not traversed before, simply add all selected outgoing edges (either hard or pending edges)
@@ -181,25 +180,16 @@ class NodeState implements DependencyGraphNode {
         }
 
         // Check if this node is still included in the graph, by looking at incoming edges.
-        boolean hasIncomingEdges = !incomingEdges.isEmpty();
         List<EdgeState> transitiveIncoming = getTransitiveIncomingEdges();
 
         // Check if there are any transitive incoming edges at all. Don't traverse if not.
         if (transitiveIncoming.isEmpty() && !isRoot()) {
-            // If node was previously traversed, need to remove outgoing edges.
-            if (previousTraversalExclusions != null) {
-                removeOutgoingEdges();
-            }
-            if (hasIncomingEdges) {
-                LOGGER.debug("{} has no transitive incoming edges. ignoring outgoing edges.", this);
-            } else {
-                LOGGER.debug("{} has no incoming edges. ignoring.", this);
-            }
+            handleNonTransitiveNode(discoveredEdges);
             return;
         }
 
         // Determine the net exclusion for this node, by inspecting all transitive incoming edges
-        ModuleExclusion resolutionFilter = getModuleResolutionFilter(transitiveIncoming);
+        ModuleExclusion resolutionFilter = getModuleResolutionFilter(incomingEdges);
 
         // Check if the was previously traversed with the same net exclusion
         if (previousTraversalExclusions != null && previousTraversalExclusions.excludesSameModulesAs(resolutionFilter)) {
@@ -215,23 +205,42 @@ class NodeState implements DependencyGraphNode {
             removeOutgoingEdges();
         }
 
-        visitDependencies(resolutionFilter, pendingDependenciesHandler, discoveredEdges);
+        visitDependencies(resolutionFilter, discoveredEdges);
         visitOwners(discoveredEdges);
     }
 
+    /**
+     * Removes outgoing edges from no longer transitive node
+     * Also process {@code belongsTo} if node still has edges at all.
+     *
+     * @param discoveredEdges In/Out parameter collecting dependencies or platforms
+     */
+    private void handleNonTransitiveNode(Collection<EdgeState> discoveredEdges) {
+        // If node was previously traversed, need to remove outgoing edges.
+        if (previousTraversalExclusions != null) {
+            removeOutgoingEdges();
+        }
+        if (!incomingEdges.isEmpty()) {
+            LOGGER.debug("{} has no transitive incoming edges. ignoring outgoing edges.", this);
+            visitOwners(discoveredEdges);
+        } else {
+            LOGGER.debug("{} has no incoming edges. ignoring.", this);
+        }
+    }
+
     /**
      * Iterate over the dependencies originating in this node, adding them either as a 'pending' dependency
      * or adding them to the `discoveredEdges` collection (and `this.outgoingEdges`)
      */
-    private void visitDependencies(ModuleExclusion resolutionFilter, PendingDependenciesHandler pendingDependenciesHandler, Collection<EdgeState> discoveredEdges) {
-        PendingDependenciesHandler.Visitor pendingDepsVisitor = pendingDependenciesHandler.start();
+    private void visitDependencies(ModuleExclusion resolutionFilter, Collection<EdgeState> discoveredEdges) {
+        PendingDependenciesVisitor pendingDepsVisitor = resolveState.newPendingDependenciesVisitor();
         try {
             for (DependencyMetadata dependency : metaData.getDependencies()) {
                 DependencyState dependencyState = new DependencyState(dependency, resolveState.getComponentSelectorConverter());
                 if (isExcluded(resolutionFilter, dependencyState)) {
                     continue;
                 }
-                dependencyState = maybeSubstitute(dependencyState);
+                dependencyState = maybeSubstitute(dependencyState, resolveState.getDependencySubstitutionApplicator());
                 if (!pendingDepsVisitor.maybeAddAsPendingDependency(this, dependencyState)) {
                     EdgeState dependencyEdge = new EdgeState(this, dependencyState, resolutionFilter, resolveState);
                     outgoingEdges.add(dependencyEdge);
@@ -256,6 +265,7 @@ class NodeState implements DependencyGraphNode {
     private void visitOwners(Collection<EdgeState> discoveredEdges) {
         ImmutableList<? extends ComponentIdentifier> owners = component.getMetadata().getPlatformOwners();
         if (!owners.isEmpty()) {
+            PendingDependenciesVisitor visitor = resolveState.newPendingDependenciesVisitor();
             for (ComponentIdentifier owner : owners) {
                 if (owner instanceof ModuleComponentIdentifier) {
                     ModuleComponentIdentifier platformId = (ModuleComponentIdentifier) owner;
@@ -265,8 +275,10 @@ class NodeState implements DependencyGraphNode {
                     // 1. the "platform" referenced is a real module, in which case we directly add it to the graph
                     // 2. the "platform" is a virtual, constructed thing, in which case we add virtual edges to the graph
                     addPlatformEdges(discoveredEdges, platformId, cs);
+                    visitor.markNotPending(platformId.getModuleIdentifier());
                 }
             }
+            visitor.complete();
         }
     }
 
@@ -280,8 +292,10 @@ class NodeState implements DependencyGraphNode {
         }
         if (metadata == null) {
             // the platform doesn't exist, so we're building a lenient one
-            metadata = new LenientPlatformResolveMetadata(platformComponentIdentifier, potentialEdge.toModuleVersionId, virtualPlatformState);
+            metadata = new LenientPlatformResolveMetadata(platformComponentIdentifier, potentialEdge.toModuleVersionId, virtualPlatformState, this, resolveState);
             potentialEdge.component.setMetadata(metadata);
+            // And now let's make sure we do not have another version of that virtual platform missing its metadata
+            potentialEdge.component.getModule().maybeCreateVirtualMetadata(resolveState);
         }
         if (virtualEdges == null) {
             virtualEdges = Lists.newArrayList();
@@ -298,8 +312,8 @@ class NodeState implements DependencyGraphNode {
      *
      * This may be better done as a decorator on ConfigurationMetadata.getDependencies()
      */
-    private DependencyState maybeSubstitute(DependencyState dependencyState) {
-        DependencySubstitutionApplicator.SubstitutionResult substitutionResult = resolveState.getDependencySubstitutionApplicator().apply(dependencyState.getDependency());
+    static DependencyState maybeSubstitute(DependencyState dependencyState, DependencySubstitutionApplicator dependencySubstitutionApplicator) {
+        DependencySubstitutionApplicator.SubstitutionResult substitutionResult = dependencySubstitutionApplicator.apply(dependencyState.getDependency());
         if (substitutionResult.hasFailure()) {
             dependencyState.failure = new ModuleVersionResolveException(dependencyState.getRequested(), substitutionResult.getFailure());
             return dependencyState;
@@ -367,12 +381,40 @@ class NodeState implements DependencyGraphNode {
         if (incomingEdges.isEmpty()) {
             return nodeExclusions;
         }
-        ModuleExclusion edgeExclusions = incomingEdges.get(0).getExclusions();
-        for (int i = 1; i < incomingEdges.size(); i++) {
-            EdgeState dependencyEdge = incomingEdges.get(i);
-            edgeExclusions = moduleExclusions.union(edgeExclusions, dependencyEdge.getExclusions());
+
+        ModuleExclusion edgeExclusions = null;
+
+        for (EdgeState dependencyEdge : incomingEdges) {
+            if (dependencyEdge.isTransitive()) {
+                // Transitive dependency
+                edgeExclusions = excludedByBoth(edgeExclusions, dependencyEdge.getExclusions());
+            } else if (dependencyEdge.getDependencyMetadata().isConstraint()) {
+                // Constraint: only consider explicit exclusions declared for this constraint
+                ModuleExclusion constraintExclusions = dependencyEdge.getEdgeExclusions();
+                nodeExclusions = excludedByEither(nodeExclusions, constraintExclusions);
+            }
         }
-        return moduleExclusions.intersect(edgeExclusions, nodeExclusions);
+        return excludedByEither(edgeExclusions, nodeExclusions);
+    }
+
+    private ModuleExclusion excludedByBoth(ModuleExclusion one, ModuleExclusion two) {
+        if (one == null) {
+            return two;
+        }
+        if (two == null) {
+            return one;
+        }
+        return resolveState.getModuleExclusions().union(one, two);
+    }
+
+    private ModuleExclusion excludedByEither(ModuleExclusion one, ModuleExclusion two) {
+        if (one == null) {
+            return two;
+        }
+        if (two == null) {
+            return one;
+        }
+        return resolveState.getModuleExclusions().intersect(one, two);
     }
 
     private void removeOutgoingEdges() {
@@ -380,6 +422,7 @@ class NodeState implements DependencyGraphNode {
             for (EdgeState outgoingDependency : outgoingEdges) {
                 outgoingDependency.removeFromTargetConfigurations();
                 outgoingDependency.getSelector().release();
+                outgoingDependency.maybeDecreaseHardEdgeCount();
             }
         }
         outgoingEdges.clear();
@@ -408,10 +451,10 @@ class NodeState implements DependencyGraphNode {
 
     private void restartIncomingEdges() {
         if (incomingEdges.size() == 1) {
-            EdgeState singleEdge = incomingEdges.iterator().next();
+            EdgeState singleEdge = incomingEdges.get(0);
             singleEdge.restart();
         } else {
-            for (EdgeState dependency : new ArrayList<EdgeState>(incomingEdges)) {
+            for (EdgeState dependency : new ArrayList<>(incomingEdges)) {
                 dependency.restart();
             }
         }
@@ -427,7 +470,7 @@ class NodeState implements DependencyGraphNode {
             previousTraversalExclusions = null;
             outgoingEdges.clear();
             virtualEdges = null;
-            resolveState.onMoreSelected(this);
+            resolveState.onFewerSelected(this);
         }
     }
 
@@ -435,4 +478,19 @@ class NodeState implements DependencyGraphNode {
         return resolveState.getAttributesFactory();
     }
 
+    /**
+     * Invoked when this node is back to being a pending dependency.
+     * There may be some incoming edges left at that point, but they must all be coming from constraints.
+     * @param pendingDependencies
+     */
+    public void clearConstraintEdges(PendingDependencies pendingDependencies) {
+        for (EdgeState incomingEdge : incomingEdges) {
+            assert incomingEdge.getDependencyMetadata().isConstraint();
+            incomingEdge.getSelector().release();
+            NodeState from = incomingEdge.getFrom();
+            from.getOutgoingEdges().remove(incomingEdge);
+            pendingDependencies.addNode(from);
+        }
+        incomingEdges.clear();
+    }
 }
