@@ -17,6 +17,10 @@ package org.gradle.api.internal.artifacts.ivyservice.resolveengine.graph.selecto
 
 import com.google.common.collect.Lists;
 import org.gradle.api.internal.artifacts.ResolvedVersionConstraint;
+import org.gradle.api.internal.artifacts.ivyservice.ivyresolve.strategy.DefaultVersionComparator;
+import org.gradle.api.internal.artifacts.ivyservice.ivyresolve.strategy.LatestVersionSelector;
+import org.gradle.api.internal.artifacts.ivyservice.ivyresolve.strategy.Version;
+import org.gradle.api.internal.artifacts.ivyservice.ivyresolve.strategy.VersionParser;
 import org.gradle.api.internal.artifacts.ivyservice.ivyresolve.strategy.VersionSelector;
 import org.gradle.api.internal.artifacts.ivyservice.resolveengine.ComponentResolutionState;
 import org.gradle.api.internal.artifacts.ivyservice.resolveengine.result.VersionSelectionReasons;
@@ -24,9 +28,12 @@ import org.gradle.internal.resolve.ModuleVersionResolveException;
 import org.gradle.internal.resolve.result.ComponentIdResolveResult;
 
 import java.util.Collections;
+import java.util.Comparator;
 import java.util.List;
 
 class SelectorStateResolverResults {
+    private static final VersionParser VERSION_PARSER = new VersionParser();
+    private static final Comparator<Version> VERSION_COMPARATOR = new DefaultVersionComparator().asVersionComparator();
     private final List<Registration> results;
 
     public SelectorStateResolverResults(int size) {
@@ -82,41 +89,61 @@ class SelectorStateResolverResults {
     /**
      * Check already resolved results for a compatible version, and use it for this dependency rather than re-resolving.
      */
-    boolean alreadyHaveResolution(ResolvableSelectorState dep) {
+    boolean alreadyHaveResolutionForSelector(ResolvableSelectorState selector) {
         for (Registration registration : results) {
             ComponentIdResolveResult discovered = registration.result;
-            if (included(dep, discovered)) {
-                results.add(new Registration(dep, discovered));
+            if (included(selector, discovered, registration.selector.isFromLock())) {
+                register(selector, discovered);
+                selector.markResolved();
                 return true;
             }
         }
         return false;
     }
 
-    void registerResolution(ResolvableSelectorState dep, ComponentIdResolveResult resolveResult) {
-        if (resolveResult.getFailure() != null) {
-            results.add(new Registration(dep, resolveResult));
-            return;
-        }
-
+    boolean replaceExistingResolutionsWithBetterResult(ComponentIdResolveResult resolveResult, boolean isFromLock) {
         // Check already-resolved dependencies and use this version if it's compatible
+        boolean replaces = false;
         for (Registration registration : results) {
-            if (included(registration.selector, resolveResult) || sameVersion(registration.result, resolveResult)) {
+            if (emptyVersion(registration.result) || sameVersion(registration.result, resolveResult) ||
+                (included(registration.selector, resolveResult, isFromLock) && lowerVersion(registration.result, resolveResult))) {
                 registration.result = resolveResult;
+                replaces = true;
             }
         }
+        return replaces;
+    }
 
-        results.add(new Registration(dep, resolveResult));
+    void register(ResolvableSelectorState selector, ComponentIdResolveResult resolveResult) {
+        results.add(new Registration(selector, resolveResult));
+    }
+
+    private boolean emptyVersion(ComponentIdResolveResult existing) {
+        if (existing.getFailure() == null) {
+            return existing.getModuleVersionId().getVersion().isEmpty();
+        }
+        return false;
     }
 
     private boolean sameVersion(ComponentIdResolveResult existing, ComponentIdResolveResult resolveResult) {
-        if (existing.getFailure()==null && resolveResult.getFailure() == null) {
+        if (existing.getFailure() == null && resolveResult.getFailure() == null) {
             return existing.getId().equals(resolveResult.getId());
         }
         return false;
     }
 
-    private boolean included(ResolvableSelectorState dep, ComponentIdResolveResult candidate) {
+    private boolean lowerVersion(ComponentIdResolveResult existing, ComponentIdResolveResult resolveResult) {
+        if (existing.getFailure() == null && resolveResult.getFailure() == null) {
+            Version existingVersion = VERSION_PARSER.transform(existing.getModuleVersionId().getVersion());
+            Version candidateVersion = VERSION_PARSER.transform(resolveResult.getModuleVersionId().getVersion());
+
+            int comparison = VERSION_COMPARATOR.compare(candidateVersion, existingVersion);
+            return comparison < 0;
+        }
+        return false;
+    }
+
+    private boolean included(ResolvableSelectorState dep, ComponentIdResolveResult candidate, boolean candidateIsFromLock) {
         if (candidate.getFailure() != null) {
             return false;
         }
@@ -124,11 +151,22 @@ class SelectorStateResolverResults {
         if (versionConstraint == null) {
             return dep.getSelector().matchesStrictly(candidate.getId());
         }
-        VersionSelector preferredSelector = versionConstraint.getPreferredSelector();
-        if (preferredSelector == null || !preferredSelector.canShortCircuitWhenVersionAlreadyPreselected()) {
-            return false;
+        VersionSelector versionSelector = versionConstraint.getRequiredSelector();
+        if (versionSelector != null &&
+            (candidateIsFromLock || versionSelector.canShortCircuitWhenVersionAlreadyPreselected())) {
+
+            if (candidateIsFromLock && versionSelector instanceof LatestVersionSelector) {
+                // Always assume a candidate from a lock will satisfy the latest version selector
+                return true;
+            }
+
+            return versionSelector.accept(candidate.getModuleVersionId().getVersion());
         }
-        return preferredSelector.accept(candidate.getModuleVersionId().getVersion());
+        return false;
+    }
+
+    public boolean isEmpty() {
+        return results.isEmpty();
     }
 
     private static class Registration {
