@@ -35,14 +35,16 @@ public class DetachedComponentResult implements ComponentResult {
     private final ComponentIdentifier componentIdentifier;
     private final DisplayName variantName;
     private final AttributeContainer variantAttributes;
+    private final String repositoryName;
 
-    public DetachedComponentResult(Long resultId, ModuleVersionIdentifier id, ComponentSelectionReason reason, ComponentIdentifier componentIdentifier, String variantName, AttributeContainer variantAttributes) {
+    public DetachedComponentResult(Long resultId, ModuleVersionIdentifier id, ComponentSelectionReason reason, ComponentIdentifier componentIdentifier, String variantName, AttributeContainer variantAttributes, String repositoryName) {
         this.resultId = resultId;
         this.id = id;
         this.reason = reason;
         this.componentIdentifier = componentIdentifier;
         this.variantName = Describables.of(variantName);
         this.variantAttributes = variantAttributes;
+        this.repositoryName = repositoryName;
     }
 
     @Override
@@ -71,4 +73,9 @@ public class DetachedComponentResult implements ComponentResult {
     public AttributeContainer getVariantAttributes() {
         return variantAttributes;
     }
+
+    @Override
+    public String getRepositoryName() {
+        return repositoryName;
+    }
 }
