@@ -18,18 +18,18 @@ package org.gradle.api.reporting.components;
 
 import org.gradle.api.DefaultTask;
 import org.gradle.api.Incubating;
-import org.gradle.api.Project;
 import org.gradle.api.internal.file.FileResolver;
+import org.gradle.api.internal.project.ProjectInternal;
 import org.gradle.api.reporting.components.internal.ComponentReportRenderer;
 import org.gradle.api.reporting.components.internal.TypeAwareBinaryRenderer;
 import org.gradle.api.tasks.TaskAction;
+import org.gradle.internal.logging.text.StyledTextOutput;
+import org.gradle.internal.logging.text.StyledTextOutputFactory;
 import org.gradle.language.base.ProjectSourceSet;
-import org.gradle.logging.StyledTextOutput;
-import org.gradle.logging.StyledTextOutputFactory;
 import org.gradle.model.ModelMap;
 import org.gradle.model.internal.registry.ModelRegistry;
 import org.gradle.model.internal.type.ModelType;
-import org.gradle.platform.base.BinarySpec;
+import org.gradle.platform.base.BinaryContainer;
 import org.gradle.platform.base.ComponentSpec;
 import org.gradle.platform.base.ComponentSpecContainer;
 
@@ -66,7 +66,8 @@ public class ComponentReport extends DefaultTask {
 
     @TaskAction
     public void report() {
-        Project project = getProject();
+        ProjectInternal project = (ProjectInternal) getProject();
+        project.prepareForRuleBasedPlugins();
 
         StyledTextOutput textOutput = getTextOutputFactory().create(ComponentReport.class);
         ComponentReportRenderer renderer = new ComponentReportRenderer(getFileResolver(), getBinaryRenderer());
@@ -91,9 +92,9 @@ public class ComponentReport extends DefaultTask {
         if (sourceSets != null) {
             renderer.renderSourceSets(sourceSets);
         }
-        ModelMap<BinarySpec> binaries = modelElement("binaries", modelMap(BinarySpec.class));
+        BinaryContainer binaries = modelElement("binaries", BinaryContainer.class);
         if (binaries != null) {
-            renderer.renderBinaries(binaries);
+            renderer.renderBinaries(binaries.values());
         }
 
         renderer.completeProject(project);
