@@ -29,10 +29,13 @@ import org.gradle.api.tasks.Internal;
 import org.gradle.api.tasks.LocalState;
 import org.gradle.api.tasks.Optional;
 import org.gradle.api.tasks.OutputFile;
+import org.gradle.internal.Factory;
 import org.gradle.internal.jacoco.JacocoAgentJar;
 import org.gradle.process.JavaForkOptions;
+import org.gradle.util.DeprecationLogger;
 import org.gradle.util.RelativePathUtil;
 
+import javax.annotation.Nullable;
 import java.io.File;
 import java.util.ArrayList;
 import java.util.Collection;
@@ -41,7 +44,6 @@ import java.util.List;
 /**
  * Extension for tasks that should run with a Jacoco agent to generate coverage execution data.
  */
-@Incubating
 public class JacocoTaskExtension {
 
     /**
@@ -107,8 +109,9 @@ public class JacocoTaskExtension {
     /**
      * The path for the execution data to be written to.
      */
-    @OutputFile
+    @Nullable
     @Optional
+    @OutputFile
     public File getDestinationFile() {
         return destinationFile.getOrNull();
     }
@@ -119,6 +122,7 @@ public class JacocoTaskExtension {
      * @param destinationFile Destination file provider
      * @since 4.0
      */
+    @Incubating
     public void setDestinationFile(Provider<File> destinationFile) {
         this.destinationFile.set(destinationFile);
     }
@@ -128,53 +132,68 @@ public class JacocoTaskExtension {
     }
 
     /**
-     * Whether or not data should be appended if the {@code destinationFile} already exists. Defaults to {@code true}.
+     * Whether or not data should be appended if the {@link #destinationFile} already exists. Defaults to {@code true}.
+     *
+     * @deprecated The Jacoco plugin now deletes the old coverage file before task execution, so the data will never be appended to an existing coverage file from another task.
+     * Use {@link org.gradle.testing.jacoco.tasks.JacocoMerge} to merge different execution files or use {@link org.gradle.testing.jacoco.tasks.JacocoReportBase#setExecutionData(FileCollection)} to generate a report from multiple execution files at once.
+     * Append is set to true for the agent since this allows multiple JVMs spawned by one task to write to the same {@link #destinationFile}.
      */
+    @Deprecated
     @Input
     public boolean isAppend() {
+        nagAboutDeprecatedAppendProperty();
         return append;
     }
 
+    @Deprecated
     public void setAppend(boolean append) {
+        nagAboutDeprecatedAppendProperty();
         this.append = append;
     }
 
+    private void nagAboutDeprecatedAppendProperty() {
+        DeprecationLogger.nagUserOfDiscontinuedProperty("append", "Append should always be true.");
+    }
+
     /**
      * List of class names that should be included in analysis. Names can use wildcards (* and ?). If left empty, all classes will be included. Defaults to an empty list.
      */
-    @Input
+    @Nullable
     @Optional
+    @Input
     public List<String> getIncludes() {
         return includes;
     }
 
-    public void setIncludes(List<String> includes) {
+    public void setIncludes(@Nullable List<String> includes) {
         this.includes = includes;
     }
 
     /**
      * List of class names that should be excluded from analysis. Names can use wildcard (* and ?). Defaults to an empty list.
      */
-    @Input
+    @Nullable
     @Optional
+    @Input
     public List<String> getExcludes() {
         return excludes;
     }
 
-    public void setExcludes(List<String> excludes) {
+    public void setExcludes(@Nullable List<String> excludes) {
         this.excludes = excludes;
     }
 
     /**
      * List of classloader names that should be excluded from analysis. Names can use wildcards (* and ?). Defaults to an empty list.
      */
-    @Input
+    @Nullable
     @Optional
+    @Input
     public List<String> getExcludeClassLoaders() {
         return excludeClassLoaders;
     }
 
-    public void setExcludeClassLoaders(List<String> excludeClassLoaders) {
+    public void setExcludeClassLoaders(@Nullable List<String> excludeClassLoaders) {
         this.excludeClassLoaders = excludeClassLoaders;
     }
 
@@ -195,13 +214,14 @@ public class JacocoTaskExtension {
     /**
      * An identifier for the session written to the execution data. Defaults to an auto-generated identifier.
      */
-    @Input
+    @Nullable
     @Optional
+    @Input
     public String getSessionId() {
         return sessionId;
     }
 
-    public void setSessionId(String sessionId) {
+    public void setSessionId(@Nullable String sessionId) {
         this.sessionId = sessionId;
     }
 
@@ -232,13 +252,14 @@ public class JacocoTaskExtension {
     /**
      * IP address or hostname to use with {@link Output#TCP_SERVER} or {@link Output#TCP_CLIENT}. Defaults to localhost.
      */
-    @Input
+    @Nullable
     @Optional
+    @Input
     public String getAddress() {
         return address;
     }
 
-    public void setAddress(String address) {
+    public void setAddress(@Nullable String address) {
         this.address = address;
     }
 
@@ -246,7 +267,6 @@ public class JacocoTaskExtension {
      * Port to bind to for {@link Output#TCP_SERVER} or {@link Output#TCP_CLIENT}. Defaults to 6300.
      */
     @Input
-    @Optional
     public int getPort() {
         return port;
     }
@@ -260,8 +280,9 @@ public class JacocoTaskExtension {
      *
      * @since 3.4
      */
-    @LocalState
+    @Nullable
     @Optional
+    @LocalState
     public File getClassDumpDir() {
         return classDumpDir;
     }
@@ -271,7 +292,7 @@ public class JacocoTaskExtension {
      *
      * @since 3.4
      */
-    public void setClassDumpDir(File classDumpDir) {
+    public void setClassDumpDir(@Nullable File classDumpDir) {
         this.classDumpDir = classDumpDir;
     }
 
@@ -296,6 +317,7 @@ public class JacocoTaskExtension {
      *
      * @since 4.6
      */
+    @Incubating
     @Classpath
     public FileCollection getAgentClasspath() {
         return agent.getAgentConf();
@@ -314,7 +336,12 @@ public class JacocoTaskExtension {
         builder.append(RelativePathUtil.relativePath(task.getWorkingDir(), agent.getJar()));
         builder.append('=');
         argument.append("destfile", getDestinationFile());
-        argument.append("append", isAppend());
+        argument.append("append", DeprecationLogger.whileDisabled(new Factory<Boolean>() {
+            @Override
+            public Boolean create() {
+                return isAppend();
+            }
+        }));
         argument.append("includes", getIncludes());
         argument.append("excludes", getExcludes());
         argument.append("exclclassloader", getExcludeClassLoaders());
@@ -346,7 +373,7 @@ public class JacocoTaskExtension {
             this.workingDirectory = workingDirectory;
         }
 
-        public void append(String name, Object value) {
+        public void append(String name, @Nullable Object value) {
             if (value != null
                 && !((value instanceof Collection) && ((Collection) value).isEmpty())
                 && !((value instanceof String) && (StringUtils.isEmpty((String) value)))
