@@ -19,9 +19,8 @@ package org.gradle.testing.jacoco.tasks;
 import com.google.common.base.Predicate;
 import com.google.common.collect.Iterables;
 import org.gradle.api.Action;
-import org.gradle.api.Incubating;
-import org.gradle.api.Project;
 import org.gradle.api.Task;
+import org.gradle.api.file.ConfigurableFileCollection;
 import org.gradle.api.file.FileCollection;
 import org.gradle.api.internal.project.IsolatedAntBuilder;
 import org.gradle.api.specs.Spec;
@@ -34,11 +33,13 @@ import org.gradle.api.tasks.SourceSet;
 import org.gradle.api.tasks.TaskCollection;
 import org.gradle.internal.reflect.Instantiator;
 import org.gradle.testing.jacoco.plugins.JacocoTaskExtension;
+import org.gradle.util.DeprecationLogger;
 
 import javax.annotation.Nullable;
 import javax.inject.Inject;
 import java.io.File;
 import java.util.Arrays;
+import java.util.Set;
 import java.util.concurrent.Callable;
 
 /**
@@ -46,14 +47,13 @@ import java.util.concurrent.Callable;
  *
  * @since 3.4
  */
-@Incubating
 public abstract class JacocoReportBase extends JacocoBase {
 
-    private FileCollection executionData;
-    private FileCollection sourceDirectories;
-    private FileCollection classDirectories;
-    private FileCollection additionalClassDirs;
-    private FileCollection additionalSourceDirs;
+    private final ConfigurableFileCollection executionData = getProject().files();
+    private final ConfigurableFileCollection sourceDirectories = getProject().files();
+    private final ConfigurableFileCollection classDirectories = getProject().files();
+    private final ConfigurableFileCollection additionalClassDirs = getProject().files();
+    private final ConfigurableFileCollection additionalSourceDirs = getProject().files();
 
     public JacocoReportBase() {
         onlyIf(new Spec<Task>() {
@@ -84,12 +84,19 @@ public abstract class JacocoReportBase extends JacocoBase {
      */
     @PathSensitive(PathSensitivity.NONE)
     @InputFiles
-    public FileCollection getExecutionData() {
+    public ConfigurableFileCollection getExecutionData() {
         return executionData;
     }
 
+    /**
+     * Collection of execution data files to analyze.
+     *
+     * @deprecated Use {@code getExecutionData().setFrom(...)}
+     */
+    @Deprecated
     public void setExecutionData(FileCollection executionData) {
-        this.executionData = executionData;
+        DeprecationLogger.nagUserOfDiscontinuedMethod("JacocoReportBase.setExecutionData(FileCollection)", "Use getExecutionData().from(...)");
+        this.executionData.setFrom(executionData);
     }
 
     /**
@@ -97,12 +104,18 @@ public abstract class JacocoReportBase extends JacocoBase {
      */
     @PathSensitive(PathSensitivity.RELATIVE)
     @InputFiles
-    public FileCollection getSourceDirectories() {
+    public ConfigurableFileCollection getSourceDirectories() {
         return sourceDirectories;
     }
 
+    /**
+     * Source sets that coverage should be reported for.
+     * @deprecated Use {@code getSourceDirectories().setFrom(...)}
+     */
+    @Deprecated
     public void setSourceDirectories(FileCollection sourceDirectories) {
-        this.sourceDirectories = sourceDirectories;
+        DeprecationLogger.nagUserOfDiscontinuedMethod("JacocoReportBase.setSourceDirectories(FileCollection)", "Use getSourceDirectories().from(...)");
+        this.sourceDirectories.setFrom(sourceDirectories);
     }
 
     /**
@@ -110,42 +123,68 @@ public abstract class JacocoReportBase extends JacocoBase {
      */
     @PathSensitive(PathSensitivity.RELATIVE)
     @InputFiles
-    public FileCollection getClassDirectories() {
+    public ConfigurableFileCollection getClassDirectories() {
         return classDirectories;
     }
 
+    /**
+     * Classes that coverage should be reported for.
+     * @deprecated Use {@code getClassDirectories().setFrom(...)}
+     */
+    @Deprecated
     public void setClassDirectories(FileCollection classDirectories) {
-        this.classDirectories = classDirectories;
+        DeprecationLogger.nagUserOfDiscontinuedMethod("JacocoReportBase.setClassDirectories(FileCollection)", "Use getClassDirectories().from(...)");
+        this.classDirectories.setFrom(classDirectories);
     }
 
     /**
      * Additional class dirs that coverage data should be reported for.
      */
-    @Nullable
     @Optional
     @PathSensitive(PathSensitivity.RELATIVE)
     @InputFiles
-    public FileCollection getAdditionalClassDirs() {
+    public ConfigurableFileCollection getAdditionalClassDirs() {
         return additionalClassDirs;
     }
 
+    /**
+     * Additional class dirs that coverage data should be reported for.
+     *
+     * @deprecated Use {@code getAdditionalClassDirs().setFrom(...)}
+     */
+    @Deprecated
     public void setAdditionalClassDirs(@Nullable FileCollection additionalClassDirs) {
-        this.additionalClassDirs = additionalClassDirs;
+        DeprecationLogger.nagUserOfDiscontinuedMethod("JacocoReportBase.setAdditionalClassDirs(FileCollection)", "Use getAdditionalClassDirs().from(...)");
+        if (additionalClassDirs!=null) {
+            this.additionalClassDirs.setFrom(additionalClassDirs);
+        } else {
+            this.additionalClassDirs.setFrom();
+        }
     }
 
     /**
      * Additional source dirs for the classes coverage data is being reported for.
      */
-    @Nullable
     @Optional
     @PathSensitive(PathSensitivity.RELATIVE)
     @InputFiles
-    public FileCollection getAdditionalSourceDirs() {
+    public ConfigurableFileCollection getAdditionalSourceDirs() {
         return additionalSourceDirs;
     }
 
+    /**
+     * Additional source dirs for the classes coverage data is being reported for.
+     *
+     * @deprecated Use {@code getAdditionalSourceDirs().setFrom(...)}
+     */
+    @Deprecated
     public void setAdditionalSourceDirs(@Nullable FileCollection additionalSourceDirs) {
-        this.additionalSourceDirs = additionalSourceDirs;
+        DeprecationLogger.nagUserOfDiscontinuedMethod("JacocoReportBase.setAdditionalSourceDirs(FileCollection)", "Use getAdditionalSourceDirs().from(...)");
+        if (additionalSourceDirs!=null) {
+            this.additionalSourceDirs.setFrom(additionalSourceDirs);
+        } else {
+            this.additionalSourceDirs.setFrom();
+        }
     }
 
     /**
@@ -154,11 +193,7 @@ public abstract class JacocoReportBase extends JacocoBase {
      * @param files one or more files to add
      */
     public void executionData(Object... files) {
-        if (executionData == null) {
-            executionData = getProject().files(files);
-        } else {
-            executionData = executionData.plus(getProject().files(files));
-        }
+        executionData.from(files);
     }
 
     /**
@@ -202,10 +237,6 @@ public abstract class JacocoReportBase extends JacocoBase {
      */
     @Internal
     public FileCollection getAllClassDirs() {
-        FileCollection additionalDirs = getAdditionalClassDirs();
-        if (additionalDirs == null) {
-            return classDirectories;
-        }
         return classDirectories.plus(getAdditionalClassDirs());
     }
 
@@ -217,10 +248,6 @@ public abstract class JacocoReportBase extends JacocoBase {
      */
     @Internal
     public FileCollection getAllSourceDirs() {
-        FileCollection additionalDirs = getAdditionalSourceDirs();
-        if (additionalDirs == null) {
-            return sourceDirectories;
-        }
         return sourceDirectories.plus(getAdditionalSourceDirs());
     }
 
@@ -231,23 +258,15 @@ public abstract class JacocoReportBase extends JacocoBase {
      * @param sourceSets one or more source sets to report on
      */
     public void sourceSets(final SourceSet... sourceSets) {
-        getProject().afterEvaluate(new Action<Project>() {
-            @Override
-            public void execute(Project project) {
-                for (SourceSet sourceSet : sourceSets) {
-                    if (getSourceDirectories() == null) {
-                        setSourceDirectories(getProject().files(sourceSet.getAllJava().getSrcDirs()));
-                    } else {
-                        setSourceDirectories(getSourceDirectories().plus(getProject().files(sourceSet.getAllJava().getSrcDirs())));
-                    }
-                    if (getClassDirectories() == null) {
-                        setClassDirectories(sourceSet.getOutput());
-                    } else {
-                        setClassDirectories(getClassDirectories().plus(sourceSet.getOutput()));
-                    }
+        for (final SourceSet sourceSet : sourceSets) {
+            sourceDirectories.from(new Callable<Set<File>>() {
+                @Override
+                public Set<File> call() throws Exception {
+                    return sourceSet.getAllJava().getSrcDirs();
                 }
-            }
-        });
+            });
+            classDirectories.from(sourceSet.getOutput());
+        }
     }
 
     /**
@@ -265,11 +284,7 @@ public abstract class JacocoReportBase extends JacocoBase {
      * @param dirs a {@code FileCollection} of directories containing classes to report coverage of
      */
     public void additionalClassDirs(FileCollection dirs) {
-        if (additionalClassDirs == null) {
-            additionalClassDirs = dirs;
-        } else {
-            additionalClassDirs = additionalClassDirs.plus(dirs);
-        }
+        additionalClassDirs.from(dirs);
     }
 
     /**
@@ -287,10 +302,6 @@ public abstract class JacocoReportBase extends JacocoBase {
      * @param dirs a {@code FileCollection} of directories containing source files for the classes included in the report
      */
     public void additionalSourceDirs(FileCollection dirs) {
-        if (additionalSourceDirs == null) {
-            additionalSourceDirs = dirs;
-        } else {
-            additionalSourceDirs = additionalSourceDirs.plus(dirs);
-        }
+        additionalSourceDirs.from(dirs);
     }
 }
