@@ -19,17 +19,20 @@ package org.gradle.plugins.javascript.coffeescript;
 import groovy.lang.Closure;
 import org.gradle.api.Action;
 import org.gradle.api.file.FileCollection;
+import org.gradle.api.file.FileTree;
 import org.gradle.api.logging.LogLevel;
+import org.gradle.api.tasks.Classpath;
 import org.gradle.api.tasks.InputFiles;
 import org.gradle.api.tasks.Nested;
-import org.gradle.api.tasks.OrderSensitive;
 import org.gradle.api.tasks.OutputDirectory;
+import org.gradle.api.tasks.PathSensitive;
+import org.gradle.api.tasks.PathSensitivity;
 import org.gradle.api.tasks.SourceTask;
 import org.gradle.api.tasks.TaskAction;
 import org.gradle.plugins.javascript.coffeescript.compile.internal.DefaultCoffeeScriptCompileSpec;
 import org.gradle.plugins.javascript.coffeescript.compile.internal.rhino.RhinoCoffeeScriptCompiler;
-import org.gradle.plugins.javascript.rhino.worker.RhinoWorkerHandleFactory;
 import org.gradle.plugins.javascript.rhino.worker.internal.DefaultRhinoWorkerHandleFactory;
+import org.gradle.plugins.javascript.rhino.worker.internal.RhinoWorkerHandleFactory;
 import org.gradle.process.internal.worker.WorkerProcessFactory;
 
 import javax.inject.Inject;
@@ -47,21 +50,48 @@ public class CoffeeScriptCompile extends SourceTask {
         throw new UnsupportedOperationException();
     }
 
+    /**
+     * {@inheritDoc}
+     */
+    @Override
+    @PathSensitive(PathSensitivity.RELATIVE)
+    public FileTree getSource() {
+        return super.getSource();
+    }
+
+    @PathSensitive(PathSensitivity.RELATIVE)
     @InputFiles
     public FileCollection getCoffeeScriptJs() {
         return getProject().files(coffeeScriptJs);
     }
 
+    /**
+     * Sets Coffee Script Javascript file.
+     *
+     * @since 4.0
+     */
+    public void setCoffeeScriptJs(FileCollection coffeeScriptJs) {
+        this.coffeeScriptJs = coffeeScriptJs;
+    }
+
     public void setCoffeeScriptJs(Object coffeeScriptJs) {
         this.coffeeScriptJs = coffeeScriptJs;
     }
 
-    @OrderSensitive
-    @InputFiles
+    @Classpath
     public FileCollection getRhinoClasspath() {
         return getProject().files(rhinoClasspath);
     }
 
+    /**
+     * Sets Rhino classpath.
+     *
+     * @since 4.0
+     */
+    public void setRhinoClasspath(FileCollection rhinoClasspath) {
+        this.rhinoClasspath = rhinoClasspath;
+    }
+
     public void setRhinoClasspath(Object rhinoClasspath) {
         this.rhinoClasspath = rhinoClasspath;
     }
@@ -71,6 +101,15 @@ public class CoffeeScriptCompile extends SourceTask {
         return getProject().file(destinationDir);
     }
 
+    /**
+     * Sets destination directory.
+     *
+     * @since 4.0
+     */
+    public void setDestinationDir(File destinationDir) {
+        this.destinationDir = destinationDir;
+    }
+
     public void setDestinationDir(Object destinationDir) {
         this.destinationDir = destinationDir;
     }
