@@ -19,18 +19,19 @@ package org.gradle.plugins.javascript.coffeescript;
 import org.gradle.api.tasks.Input;
 import org.gradle.api.tasks.Optional;
 
+import javax.annotation.Nullable;
 import java.io.Serializable;
 
 public class CoffeeScriptCompileOptions implements Serializable {
 
     private String encoding = "UTF-8";
 
-    @Optional @Input
+    @Nullable @Optional @Input
     public String getEncoding() {
         return encoding;
     }
 
-    public void setEncoding(String encoding) {
+    public void setEncoding(@Nullable String encoding) {
         this.encoding = encoding;
     }
 }
