@@ -20,12 +20,15 @@ import com.google.gson.GsonBuilder;
 import org.gradle.api.GradleException;
 import org.gradle.api.UncheckedIOException;
 import org.gradle.api.file.FileCollection;
+import org.gradle.api.file.FileTree;
 import org.gradle.api.logging.LogLevel;
 import org.gradle.api.logging.Logger;
 import org.gradle.api.tasks.Classpath;
 import org.gradle.api.tasks.Input;
 import org.gradle.api.tasks.InputFiles;
 import org.gradle.api.tasks.OutputFile;
+import org.gradle.api.tasks.PathSensitive;
+import org.gradle.api.tasks.PathSensitivity;
 import org.gradle.api.tasks.SourceTask;
 import org.gradle.api.tasks.TaskAction;
 import org.gradle.api.tasks.TaskExecutionException;
@@ -33,8 +36,8 @@ import org.gradle.plugins.javascript.jshint.internal.JsHintProtocol;
 import org.gradle.plugins.javascript.jshint.internal.JsHintResult;
 import org.gradle.plugins.javascript.jshint.internal.JsHintSpec;
 import org.gradle.plugins.javascript.jshint.internal.JsHintWorker;
-import org.gradle.plugins.javascript.rhino.worker.RhinoWorkerHandleFactory;
 import org.gradle.plugins.javascript.rhino.worker.internal.DefaultRhinoWorkerHandleFactory;
+import org.gradle.plugins.javascript.rhino.worker.internal.RhinoWorkerHandleFactory;
 import org.gradle.process.internal.worker.WorkerProcessFactory;
 
 import javax.inject.Inject;
@@ -57,20 +60,48 @@ public class JsHint extends SourceTask {
         throw new UnsupportedOperationException();
     }
 
+    /**
+     * {@inheritDoc}
+     */
+    @Override
+    @PathSensitive(PathSensitivity.RELATIVE)
+    public FileTree getSource() {
+        return super.getSource();
+    }
+
     @Classpath
     public FileCollection getRhinoClasspath() {
         return getProject().files(rhinoClasspath);
     }
 
+    /**
+     * Sets Rhino classpath.
+     *
+     * @since 4.0
+     */
+    public void setRhinoClasspath(FileCollection rhinoClasspath) {
+        this.rhinoClasspath = rhinoClasspath;
+    }
+
     public void setRhinoClasspath(Object rhinoClasspath) {
         this.rhinoClasspath = rhinoClasspath;
     }
 
+    @PathSensitive(PathSensitivity.RELATIVE)
     @InputFiles
     public FileCollection getJsHint() {
         return getProject().files(jsHint);
     }
 
+    /**
+     * Sets jshint file.
+     *
+     * @since 4.0
+     */
+    public void setJsHint(FileCollection jsHint) {
+        this.jsHint = jsHint;
+    }
+
     public void setJsHint(Object jsHint) {
         this.jsHint = jsHint;
     }
@@ -89,6 +120,15 @@ public class JsHint extends SourceTask {
         return jsonReport == null ? null : getProject().file(jsonReport);
     }
 
+    /**
+     * Sets JSON report file.
+     *
+     * @since 4.0
+     */
+    public void setJsonReport(File jsonReport) {
+        this.jsonReport = jsonReport;
+    }
+
     public void setJsonReport(Object jsonReport) {
         this.jsonReport = jsonReport;
     }
