@@ -22,6 +22,7 @@ import org.gradle.api.Incubating;
 import org.gradle.api.Plugin;
 import org.gradle.api.Project;
 import org.gradle.api.Task;
+import org.gradle.api.Transformer;
 import org.gradle.api.artifacts.Configuration;
 import org.gradle.api.artifacts.ConfigurationContainer;
 import org.gradle.api.artifacts.ModuleVersionIdentifier;
@@ -33,6 +34,7 @@ import org.gradle.api.component.ComponentWithVariants;
 import org.gradle.api.component.PublishableComponent;
 import org.gradle.api.component.SoftwareComponent;
 import org.gradle.api.component.SoftwareComponentContainer;
+import org.gradle.api.file.Directory;
 import org.gradle.api.file.DirectoryProperty;
 import org.gradle.api.file.FileCollection;
 import org.gradle.api.file.RegularFile;
@@ -45,6 +47,7 @@ import org.gradle.api.publish.maven.MavenPublication;
 import org.gradle.api.publish.maven.internal.publication.MavenPublicationInternal;
 import org.gradle.api.publish.maven.internal.publisher.MutableMavenProjectIdentity;
 import org.gradle.api.tasks.TaskContainer;
+import org.gradle.api.tasks.TaskProvider;
 import org.gradle.internal.Cast;
 import org.gradle.language.ComponentWithBinaries;
 import org.gradle.language.ComponentWithOutputs;
@@ -150,12 +153,22 @@ public class NativeBasePlugin implements Plugin<ProjectInternal> {
                         @Override
                         public void execute(ComponentWithOutputs binary) {
                             // Determine which output to produce at development time.
-                            FileCollection outputs = binary.getOutputs();
+                            final FileCollection outputs = binary.getOutputs();
                             Names names = ((ComponentWithNames) binary).getNames();
-                            Task lifecycleTask = tasks.create(names.getTaskName("assemble"));
-                            lifecycleTask.dependsOn(outputs);
+                            tasks.register(names.getTaskName("assemble"), new Action<Task>() {
+                                @Override
+                                public void execute(Task lifecycleTask) {
+                                    lifecycleTask.dependsOn(outputs);
+                                }
+                            });
+
                             if (binary == ((ProductionComponent) component).getDevelopmentBinary().get()) {
-                                tasks.getByName(LifecycleBasePlugin.ASSEMBLE_TASK_NAME).dependsOn(outputs);
+                                tasks.named(LifecycleBasePlugin.ASSEMBLE_TASK_NAME, new Action<Task>() {
+                                    @Override
+                                    public void execute(Task task) {
+                                        task.dependsOn(outputs);
+                                    }
+                                });
                             }
                         }
                     });
@@ -169,26 +182,36 @@ public class NativeBasePlugin implements Plugin<ProjectInternal> {
             @Override
             public void execute(final ConfigurableComponentWithExecutable executable) {
                 final Names names = executable.getNames();
-                NativeToolChain toolChain = executable.getToolChain();
-                NativePlatform targetPlatform = executable.getTargetPlatform();
+                final NativeToolChain toolChain = executable.getToolChain();
+                final NativePlatform targetPlatform = executable.getTargetPlatform();
+                final PlatformToolProvider toolProvider = executable.getPlatformToolProvider();
 
                 // Add a link task
-                LinkExecutable link = tasks.create(names.getTaskName("link"), LinkExecutable.class);
-                link.source(executable.getObjects());
-                link.lib(executable.getLinkLibraries());
-                final PlatformToolProvider toolProvider = executable.getPlatformToolProvider();
-                link.getLinkedFile().set(buildDirectory.file(providers.provider(new Callable<String>() {
+                TaskProvider<LinkExecutable> link = tasks.register(names.getTaskName("link"), LinkExecutable.class, new Action<LinkExecutable>() {
                     @Override
-                    public String call() {
-                        return toolProvider.getExecutableName("exe/" + names.getDirName() + executable.getBaseName().get());
+                    public void execute(LinkExecutable link) {
+                        link.source(executable.getObjects());
+                        link.lib(executable.getLinkLibraries());
+                        link.getLinkedFile().set(buildDirectory.file(providers.provider(new Callable<String>() {
+                            @Override
+                            public String call() {
+                                return toolProvider.getExecutableName("exe/" + names.getDirName() + executable.getBaseName().get());
+                            }
+                        })));
+                        link.getTargetPlatform().set(targetPlatform);
+                        link.getToolChain().set(toolChain);
+                        link.getDebuggable().set(executable.isDebuggable());
+
                     }
-                })));
-                link.getTargetPlatform().set(targetPlatform);
-                link.getToolChain().set(toolChain);
-                link.getDebuggable().set(executable.isDebuggable());
+                });
 
                 executable.getLinkTask().set(link);
-                executable.getDebuggerExecutableFile().set(link.getLinkedFile());
+                executable.getDebuggerExecutableFile().set(link.flatMap(new Transformer<Provider<? extends RegularFile>, LinkExecutable>() {
+                    @Override
+                    public Provider<? extends RegularFile> transform(LinkExecutable linkExecutable) {
+                        return linkExecutable.getLinkedFile();
+                    }
+                }));
 
                 if (executable.isDebuggable() && executable.isOptimized() && toolProvider.requiresDebugBinaryStripping()) {
                     Provider<RegularFile> symbolLocation = buildDirectory.file(providers.provider(new Callable<String>() {
@@ -203,30 +226,60 @@ public class NativeBasePlugin implements Plugin<ProjectInternal> {
                             return toolProvider.getExecutableName("exe/" + names.getDirName() + "stripped/" + executable.getBaseName().get());
                         }
                     }));
-                    StripSymbols stripSymbols = stripSymbols(link, names, tasks, toolChain, targetPlatform, strippedLocation);
-                    executable.getExecutableFile().set(stripSymbols.getOutputFile());
-                    ExtractSymbols extractSymbols = extractSymbols(link, names, tasks, toolChain, targetPlatform, symbolLocation);
-                    executable.getOutputs().from(extractSymbols.getSymbolFile());
+                    TaskProvider<StripSymbols> stripSymbols = stripSymbols(link, names, tasks, toolChain, targetPlatform, strippedLocation);
+                    executable.getExecutableFile().set(stripSymbols.flatMap(new Transformer<Provider<? extends RegularFile>, StripSymbols>() {
+                        @Override
+                        public Provider<? extends RegularFile> transform(StripSymbols stripSymbols) {
+                            return stripSymbols.getOutputFile();
+                        }
+                    }));
+                    TaskProvider<ExtractSymbols> extractSymbols = extractSymbols(link, names, tasks, toolChain, targetPlatform, symbolLocation);
+                    executable.getOutputs().from(extractSymbols.flatMap(new Transformer<Provider<? extends RegularFile>, ExtractSymbols>() {
+                        @Override
+                        public Provider<? extends RegularFile> transform(ExtractSymbols extractSymbols) {
+                            return extractSymbols.getSymbolFile();
+                        }
+                    }));
                 } else {
-                    executable.getExecutableFile().set(link.getLinkedFile());
+                    executable.getExecutableFile().set(link.flatMap(new Transformer<Provider<? extends RegularFile>, LinkExecutable>() {
+                        @Override
+                        public Provider<? extends RegularFile> transform(LinkExecutable linkExecutable) {
+                            return linkExecutable.getLinkedFile();
+                        }
+                    }));
                 }
 
                 // Add an install task
                 // TODO - should probably not add this for all executables?
                 // TODO - add stripped symbols to the installation
-                final InstallExecutable install = tasks.create(names.getTaskName("install"), InstallExecutable.class);
-                install.getTargetPlatform().set(targetPlatform);
-                install.getToolChain().set(toolChain);
-                install.getInstallDirectory().set(buildDirectory.dir("install/" + names.getDirName()));
-                install.getExecutableFile().set(executable.getExecutableFile());
-                install.lib(executable.getRuntimeLibraries());
+                final TaskProvider<InstallExecutable> install = tasks.register(names.getTaskName("install"), InstallExecutable.class, new Action<InstallExecutable>() {
+                    @Override
+                    public void execute(InstallExecutable install) {
+                        install.getTargetPlatform().set(targetPlatform);
+                        install.getToolChain().set(toolChain);
+                        install.getInstallDirectory().set(buildDirectory.dir("install/" + names.getDirName()));
+                        install.getExecutableFile().set(executable.getExecutableFile());
+                        install.lib(executable.getRuntimeLibraries());
+
+                    }
+                });
 
                 executable.getInstallTask().set(install);
-                executable.getInstallDirectory().set(install.getInstallDirectory());
+                executable.getInstallDirectory().set(install.flatMap(new Transformer<Provider<? extends Directory>, InstallExecutable>() {
+                    @Override
+                    public Provider<? extends Directory> transform(InstallExecutable installExecutable) {
+                        return installExecutable.getInstallDirectory();
+                    }
+                }));
 
                 executable.getOutputs().from(executable.getInstallDirectory());
 
-                executable.getDebuggerExecutableFile().set(install.getInstalledExecutable());
+                executable.getDebuggerExecutableFile().set(install.flatMap(new Transformer<Provider<? extends RegularFile>, InstallExecutable>() {
+                    @Override
+                    public Provider<? extends RegularFile> transform(InstallExecutable installExecutable) {
+                        return installExecutable.getInstalledExecutable();
+                    }
+                }));
             }
         });
     }
@@ -236,38 +289,61 @@ public class NativeBasePlugin implements Plugin<ProjectInternal> {
             @Override
             public void execute(final ConfigurableComponentWithSharedLibrary library) {
                 final Names names = library.getNames();
-                NativePlatform targetPlatform = library.getTargetPlatform();
-                NativeToolChain toolChain = library.getToolChain();
+                final NativePlatform targetPlatform = library.getTargetPlatform();
+                final NativeToolChain toolChain = library.getToolChain();
+                final PlatformToolProvider toolProvider = library.getPlatformToolProvider();
 
                 // Add a link task
-                final LinkSharedLibrary link = tasks.create(names.getTaskName("link"), LinkSharedLibrary.class);
-                link.source(library.getObjects());
-                link.lib(library.getLinkLibraries());
-                // TODO - need to set soname
-                final PlatformToolProvider toolProvider = library.getPlatformToolProvider();
-                Provider<RegularFile> runtimeFile = buildDirectory.file(providers.provider(new Callable<String>() {
+                final TaskProvider<LinkSharedLibrary> link = tasks.register(names.getTaskName("link"), LinkSharedLibrary.class, new Action<LinkSharedLibrary>() {
                     @Override
-                    public String call() {
-                        return toolProvider.getSharedLibraryName("lib/" + names.getDirName() + library.getBaseName().get());
+                    public void execute(LinkSharedLibrary link) {
+                        link.source(library.getObjects());
+                        link.lib(library.getLinkLibraries());
+                        // TODO - need to set soname
+                        link.getLinkedFile().set(buildDirectory.file(providers.provider(new Callable<String>() {
+                            @Override
+                            public String call() {
+                                return toolProvider.getSharedLibraryName("lib/" + names.getDirName() + library.getBaseName().get());
+                            }
+                        })));
+                        link.getTargetPlatform().set(targetPlatform);
+                        link.getToolChain().set(toolChain);
+                        link.getDebuggable().set(library.isDebuggable());
                     }
-                }));
-                link.getLinkedFile().set(runtimeFile);
-                link.getTargetPlatform().set(targetPlatform);
-                link.getToolChain().set(toolChain);
-                link.getDebuggable().set(library.isDebuggable());
+                });
 
-                Provider<RegularFile> linkFile = link.getLinkedFile();
-                runtimeFile = link.getLinkedFile();
+
+                Provider<RegularFile> linkFile = link.flatMap(new Transformer<Provider<? extends RegularFile>, LinkSharedLibrary>() {
+                    @Override
+                    public Provider<? extends RegularFile> transform(LinkSharedLibrary linkSharedLibrary) {
+                        return linkSharedLibrary.getLinkedFile();
+                    }
+                });
+                Provider<RegularFile> runtimeFile = link.flatMap(new Transformer<Provider<? extends RegularFile>, LinkSharedLibrary>() {
+                    @Override
+                    public Provider<? extends RegularFile> transform(LinkSharedLibrary linkSharedLibrary) {
+                        return linkSharedLibrary.getLinkedFile();
+                    }
+                });
 
                 if (toolProvider.producesImportLibrary()) {
-                    Provider<RegularFile> importLibrary = buildDirectory.file(providers.provider(new Callable<String>() {
+                    link.configure(new Action<LinkSharedLibrary>() {
                         @Override
-                        public String call() {
-                            return toolProvider.getImportLibraryName("lib/" + names.getDirName() + library.getBaseName().get());
+                        public void execute(LinkSharedLibrary linkSharedLibrary) {
+                            linkSharedLibrary.getImportLibrary().set(buildDirectory.file(providers.provider(new Callable<String>() {
+                                @Override
+                                public String call() {
+                                    return toolProvider.getImportLibraryName("lib/" + names.getDirName() + library.getBaseName().get());
+                                }
+                            })));
                         }
-                    }));
-                    link.getImportLibrary().set(importLibrary);
-                    linkFile = link.getImportLibrary();
+                    });
+                    linkFile = link.flatMap(new Transformer<Provider<? extends RegularFile>, LinkSharedLibrary>() {
+                        @Override
+                        public Provider<? extends RegularFile> transform(LinkSharedLibrary linkSharedLibrary) {
+                            return linkSharedLibrary.getImportLibrary();
+                        }
+                    });
                 }
 
                 if (library.isDebuggable() && library.isOptimized() && toolProvider.requiresDebugBinaryStripping()) {
@@ -283,12 +359,22 @@ public class NativeBasePlugin implements Plugin<ProjectInternal> {
                             return toolProvider.getSharedLibraryName("lib/" + names.getDirName() + "stripped/" + library.getBaseName().get());
                         }
                     }));
-                    StripSymbols stripSymbols = stripSymbols(link, names, tasks, toolChain, targetPlatform, strippedLocation);
-                    runtimeFile = stripSymbols.getOutputFile();
-                    linkFile = stripSymbols.getOutputFile();
 
-                    ExtractSymbols extractSymbols = extractSymbols(link, names, tasks, toolChain, targetPlatform, symbolLocation);
-                    library.getOutputs().from(extractSymbols.getSymbolFile());
+                    TaskProvider<StripSymbols> stripSymbols = stripSymbols(link, names, tasks, toolChain, targetPlatform, strippedLocation);
+                    linkFile = runtimeFile = stripSymbols.flatMap(new Transformer<Provider<? extends RegularFile>, StripSymbols>() {
+                        @Override
+                        public Provider<? extends RegularFile> transform(StripSymbols stripSymbols) {
+                            return stripSymbols.getOutputFile();
+                        }
+                    });
+
+                    TaskProvider<ExtractSymbols> extractSymbols = extractSymbols(link, names, tasks, toolChain, targetPlatform, symbolLocation);
+                    library.getOutputs().from(extractSymbols.flatMap(new Transformer<Provider<? extends RegularFile>, ExtractSymbols>() {
+                        @Override
+                        public Provider<? extends RegularFile> transform(ExtractSymbols extractSymbols) {
+                            return extractSymbols.getSymbolFile();
+                        }
+                    }));
                 }
                 library.getLinkTask().set(link);
                 library.getLinkFile().set(linkFile);
@@ -306,21 +392,30 @@ public class NativeBasePlugin implements Plugin<ProjectInternal> {
                 final Names names = library.getNames();
 
                 // Add a create task
-                final CreateStaticLibrary createTask = tasks.create(names.getTaskName("create"), CreateStaticLibrary.class);
-                createTask.source(library.getObjects());
-                final PlatformToolProvider toolProvider = library.getPlatformToolProvider();
-                Provider<RegularFile> linktimeFile = buildDirectory.file(providers.provider(new Callable<String>() {
+                final TaskProvider<CreateStaticLibrary> createTask = tasks.register(names.getTaskName("create"), CreateStaticLibrary.class, new Action<CreateStaticLibrary>() {
                     @Override
-                    public String call() {
-                        return toolProvider.getStaticLibraryName("lib/" + names.getDirName() + library.getBaseName().get());
+                    public void execute(CreateStaticLibrary createTask) {
+                        createTask.source(library.getObjects());
+                        final PlatformToolProvider toolProvider = library.getPlatformToolProvider();
+                        Provider<RegularFile> linktimeFile = buildDirectory.file(providers.provider(new Callable<String>() {
+                            @Override
+                            public String call() {
+                                return toolProvider.getStaticLibraryName("lib/" + names.getDirName() + library.getBaseName().get());
+                            }
+                        }));
+                        createTask.getOutputFile().set(linktimeFile);
+                        createTask.getTargetPlatform().set(library.getTargetPlatform());
+                        createTask.getToolChain().set(library.getToolChain());
                     }
-                }));
-                createTask.getOutputFile().set(linktimeFile);
-                createTask.getTargetPlatform().set(library.getTargetPlatform());
-                createTask.getToolChain().set(library.getToolChain());
+                });
 
                 // Wire the task into the library model
-                library.getLinkFile().set(createTask.getBinaryFile());
+                library.getLinkFile().set(createTask.flatMap(new Transformer<Provider<? extends RegularFile>, CreateStaticLibrary>() {
+                    @Override
+                    public Provider<? extends RegularFile> transform(CreateStaticLibrary createStaticLibrary) {
+                        return createStaticLibrary.getBinaryFile();
+                    }
+                }));
                 library.getCreateTask().set(createTask);
                 library.getOutputs().from(library.getLinkFile());
             }
@@ -453,24 +548,39 @@ public class NativeBasePlugin implements Plugin<ProjectInternal> {
         }
     }
 
-    private StripSymbols stripSymbols(AbstractLinkTask link, Names names, TaskContainer tasks, NativeToolChain toolChain, NativePlatform currentPlatform, Provider<RegularFile> strippedLocation) {
-        StripSymbols stripSymbols = tasks.create(names.getTaskName("stripSymbols"), StripSymbols.class);
-        stripSymbols.getBinaryFile().set(link.getLinkedFile());
-        stripSymbols.getOutputFile().set(strippedLocation);
-        stripSymbols.getTargetPlatform().set(currentPlatform);
-        stripSymbols.getToolChain().set(toolChain);
+    private TaskProvider<StripSymbols> stripSymbols(final TaskProvider<? extends AbstractLinkTask> link, Names names, TaskContainer tasks, final NativeToolChain toolChain, final NativePlatform currentPlatform, final Provider<RegularFile> strippedLocation) {
+        return tasks.register(names.getTaskName("stripSymbols"), StripSymbols.class, new Action<StripSymbols>() {
+            @Override
+            public void execute(StripSymbols stripSymbols) {
+                stripSymbols.getBinaryFile().set(link.flatMap(new Transformer<Provider<? extends RegularFile>, AbstractLinkTask>() {
+                    @Override
+                    public Provider<? extends RegularFile> transform(AbstractLinkTask abstractLinkTask) {
+                        return abstractLinkTask.getLinkedFile();
+                    }
+                }));
+                stripSymbols.getOutputFile().set(strippedLocation);
+                stripSymbols.getTargetPlatform().set(currentPlatform);
+                stripSymbols.getToolChain().set(toolChain);
 
-        return stripSymbols;
+            }
+        });
     }
 
-    private ExtractSymbols extractSymbols(AbstractLinkTask link, Names names, TaskContainer tasks, NativeToolChain toolChain, NativePlatform currentPlatform, Provider<RegularFile> symbolLocation) {
-        ExtractSymbols extractSymbols = tasks.create(names.getTaskName("extractSymbols"), ExtractSymbols.class);
-        extractSymbols.getBinaryFile().set(link.getLinkedFile());
-        extractSymbols.getSymbolFile().set(symbolLocation);
-        extractSymbols.getTargetPlatform().set(currentPlatform);
-        extractSymbols.getToolChain().set(toolChain);
-
-        return extractSymbols;
+    private TaskProvider<ExtractSymbols> extractSymbols(final TaskProvider<? extends AbstractLinkTask> link, Names names, TaskContainer tasks, final NativeToolChain toolChain, final NativePlatform currentPlatform, final Provider<RegularFile> symbolLocation) {
+        return tasks.register(names.getTaskName("extractSymbols"), ExtractSymbols.class, new Action<ExtractSymbols>() {
+            @Override
+            public void execute(ExtractSymbols extractSymbols) {
+                extractSymbols.getBinaryFile().set(link.flatMap(new Transformer<Provider<? extends RegularFile>, AbstractLinkTask>() {
+                    @Override
+                    public Provider<? extends RegularFile> transform(AbstractLinkTask abstractLinkTask) {
+                        return abstractLinkTask.getLinkedFile();
+                    }
+                }));
+                extractSymbols.getSymbolFile().set(symbolLocation);
+                extractSymbols.getTargetPlatform().set(currentPlatform);
+                extractSymbols.getToolChain().set(toolChain);
+            }
+        });
     }
 
     static class LinkageSelectionRule implements AttributeDisambiguationRule<Linkage> {
