@@ -97,15 +97,15 @@ public class SwiftCompile extends DefaultTask {
 
         ObjectFactory objectFactory = getProject().getObjects();
         this.moduleName = objectFactory.property(String.class);
-        this.moduleFile = newOutputFile();
+        this.moduleFile = objectFactory.fileProperty();
         this.modules = getProject().files();
-        this.compilerArgs = objectFactory.listProperty(String.class);
-        this.objectFileDir = newOutputDirectory();
+        this.compilerArgs = objectFactory.listProperty(String.class).empty();
+        this.objectFileDir = objectFactory.directoryProperty();
         this.source = getProject().files();
         this.sourceCompatibility = objectFactory.property(SwiftVersion.class);
-        this.macros = objectFactory.listProperty(String.class);
-        this.debuggable = objectFactory.property(Boolean.class);
-        this.optimize = objectFactory.property(Boolean.class);
+        this.macros = objectFactory.listProperty(String.class).empty();
+        this.debuggable = objectFactory.property(Boolean.class).value(false);
+        this.optimize = objectFactory.property(Boolean.class).value(false);
         this.targetPlatform = objectFactory.property(NativePlatform.class);
         this.toolChain = objectFactory.property(NativeToolChain.class);
     }
