@@ -48,7 +48,6 @@ import org.gradle.internal.time.Clock;
 import org.gradle.launcher.exec.BuildActionExecuter;
 import org.gradle.launcher.exec.BuildActionParameters;
 import org.gradle.util.DisconnectableInputStream;
-import org.gradle.util.SingleMessageLogger;
 
 public class ContinuousBuildActionExecuter implements BuildActionExecuter<BuildActionParameters> {
     private final BuildActionExecuter<BuildActionParameters> delegate;
@@ -71,23 +70,22 @@ public class ContinuousBuildActionExecuter implements BuildActionExecuter<BuildA
     public Object execute(BuildAction action, BuildRequestContext requestContext, final BuildActionParameters actionParameters, ServiceRegistry buildSessionScopeServices) {
         BuildCancellationToken cancellationToken = requestContext.getCancellationToken();
         if (actionParameters.isContinuous()) {
-            SingleMessageLogger.incubatingFeatureUsed("Continuous build");
             DefaultContinuousExecutionGate alwaysOpenExecutionGate = new DefaultContinuousExecutionGate();
-            final CancellableOperationManager cancellableOperationManager = createCancellableOperationManager(actionParameters, cancellationToken);
+            final CancellableOperationManager cancellableOperationManager = createCancellableOperationManager(requestContext, cancellationToken);
             return executeMultipleBuilds(action, requestContext, actionParameters, buildSessionScopeServices, cancellableOperationManager, alwaysOpenExecutionGate);
         } else {
             try {
                 return delegate.execute(action, requestContext, actionParameters, buildSessionScopeServices);
             } finally {
-                final CancellableOperationManager cancellableOperationManager = createCancellableOperationManager(actionParameters, cancellationToken);
+                final CancellableOperationManager cancellableOperationManager = createCancellableOperationManager(requestContext, cancellationToken);
                 waitForDeployments(action, requestContext, actionParameters, buildSessionScopeServices, cancellableOperationManager);
             }
         }
     }
 
-    private CancellableOperationManager createCancellableOperationManager(BuildActionParameters actionParameters, BuildCancellationToken cancellationToken) {
+    private CancellableOperationManager createCancellableOperationManager(BuildRequestContext requestContext, BuildCancellationToken cancellationToken) {
         final CancellableOperationManager cancellableOperationManager;
-        if (actionParameters.isInteractive()) {
+        if (requestContext.isInteractive()) {
             if (!(System.in instanceof DisconnectableInputStream)) {
                 System.setIn(new DisconnectableInputStream(System.in));
             }
@@ -113,7 +111,7 @@ public class ContinuousBuildActionExecuter implements BuildActionExecuter<BuildA
         cancellableOperationManager.closeInput();
     }
 
-    private Object executeMultipleBuilds(BuildAction action, BuildRequestContext requestContext, final BuildActionParameters actionParameters, final ServiceRegistry buildSessionScopeServices,
+    private Object executeMultipleBuilds(BuildAction action, final BuildRequestContext requestContext, final BuildActionParameters actionParameters, final ServiceRegistry buildSessionScopeServices,
                                          CancellableOperationManager cancellableOperationManager, ContinuousExecutionGate continuousExecutionGate) {
         BuildCancellationToken cancellationToken = requestContext.getCancellationToken();
         BuildStartedTime buildStartedTime = buildSessionScopeServices.get(BuildStartedTime.class);
@@ -144,7 +142,7 @@ public class ContinuousBuildActionExecuter implements BuildActionExecuter<BuildA
                             waiter.wait(new Runnable() {
                                 @Override
                                 public void run() {
-                                    logger.println().println("Waiting for changes to input files of tasks..." + determineExitHint(actionParameters));
+                                    logger.println().println("Waiting for changes to input files of tasks..." + determineExitHint(requestContext));
                                 }
                             }, reporter);
                             if (!cancellationToken.isCancellationRequested()) {
@@ -172,8 +170,8 @@ public class ContinuousBuildActionExecuter implements BuildActionExecuter<BuildA
         return lastResult;
     }
 
-    private String determineExitHint(BuildActionParameters actionParameters) {
-        if (actionParameters.isInteractive()) {
+    private String determineExitHint(BuildRequestContext requestContext) {
+        if (requestContext.isInteractive()) {
             if (operatingSystem.isWindows()) {
                 return " (ctrl-d then enter to exit)";
             } else {
