@@ -16,18 +16,9 @@
 
 package org.gradle.logging;
 
-import org.gradle.api.logging.LogLevel;
-
 /**
  * This type was accidentally leaked into the public API, please do not refer to it.
  */
 @Deprecated
 public interface StyledTextOutputFactory {
-    StyledTextOutput create(Class logCategory);
-
-    StyledTextOutput create(String logCategory);
-
-    StyledTextOutput create(Class logCategory, LogLevel logLevel);
-
-    StyledTextOutput create(String logCategory, LogLevel logLevel);
 }
