@@ -62,20 +62,25 @@ public class SingleMessageLogger {
 
     public static void nagUserOfReplacedPlugin(String pluginName, String replacement) {
         if (isEnabled()) {
-            nagUserWith(String.format("The %s plugin %s has been deprecated.", pluginName),
-                getRemovalDetails(),
-                String.format("Please use the %s plugin instead.", replacement),
-                null,
-                DeprecatedFeatureUsage.Type.USER_CODE_DIRECT);
+            nagUserOfDeprecatedPlugin(pluginName, String.format("Please use the %s plugin instead.", replacement));
         }
     }
 
     public static void nagUserOfPluginReplacedWithExternalOne(String pluginName, String replacement) {
         if (isEnabled()) {
-            nagUserWith(
-                String.format("The %s plugin has been deprecated.", pluginName),
-                getRemovalDetails(),
-                String.format("Consider using the %s plugin instead.", replacement),
+            nagUserOfDeprecatedPlugin(pluginName, String.format("Consider using the %s plugin instead.", replacement));
+        }
+    }
+
+    public static void nagUserOfDeprecatedPlugin(String pluginName) {
+        nagUserOfDeprecatedPlugin(pluginName, null);
+    }
+
+    public static void nagUserOfDeprecatedPlugin(String pluginName, @Nullable String advice) {
+        if (isEnabled()) {
+            nagUserWith(String.format("The %s plugin has been deprecated.", pluginName),
+                thisWillBeRemovedMessage(),
+                advice,
                 null,
                 DeprecatedFeatureUsage.Type.USER_CODE_DIRECT);
         }
@@ -121,12 +126,43 @@ public class SingleMessageLogger {
         }
     }
 
-    public static void nagUserOfReplacedMethodWithCustomRemoval(String methodName, String replacement, String removalDetails) {
+    /**
+     * Use for a method that is not deprecated, but something about the method parameters or state is deprecated.
+     */
+    public static void nagUserOfDiscontinuedMethodInvocation(String invocation) {
         if (isEnabled()) {
             nagUserWith(
-                String.format("The %s method has been deprecated.", methodName),
-                removalDetails,
-                String.format("Please use the %s method instead.", replacement),
+                String.format("Using method %s has been deprecated.", invocation),
+                thisWillBecomeAnError(),
+                null,
+                null,
+                DeprecatedFeatureUsage.Type.USER_CODE_DIRECT);
+        }
+    }
+
+    /**
+     * Use for some operation that is not deprecated, but something about the method parameters or state is deprecated.
+     */
+    public static void nagUserOfDiscontinuedInvocation(String invocation) {
+        if (isEnabled()) {
+            nagUserWith(
+                String.format("%s has been deprecated.", invocation),
+                thisWillBecomeAnError(),
+                null,
+                null,
+                DeprecatedFeatureUsage.Type.USER_CODE_DIRECT);
+        }
+    }
+
+    /**
+     * Use for a method that is not deprecated, but something about the method parameters or state is deprecated.
+     */
+    public static void nagUserOfReplacedMethodInvocation(String invocation, String replacement) {
+        if (isEnabled()) {
+            nagUserWith(
+                String.format("Using method %s has been deprecated.", invocation),
+                thisWillBecomeAnError(),
+                String.format(String.format("Please use the %s method instead.", replacement)),
                 null,
                 DeprecatedFeatureUsage.Type.USER_CODE_DIRECT);
         }
@@ -179,16 +215,6 @@ public class SingleMessageLogger {
         }
     }
 
-    public static void nagUserOfDiscontinuedApi(String api, String advice) {
-        if (isEnabled()) {
-            nagUserWith(String.format("The %s has been deprecated.", api),
-                thisWillBeRemovedMessage(),
-                advice,
-                null,
-                DeprecatedFeatureUsage.Type.USER_CODE_DIRECT);
-        }
-    }
-
     public static void nagUserOfReplacedNamedParameter(String parameterName, String replacement) {
         if (isEnabled()) {
             nagUserWith(String.format("The %s named parameter has been deprecated.", parameterName),
@@ -253,7 +279,7 @@ public class SingleMessageLogger {
         }
     }
 
-    public static void nagUserWith(String summary, String removalDetails, String advice, String contextualAdvice) {
+    public static void nagUserWith(String summary, String removalDetails, @Nullable String advice, @Nullable String contextualAdvice) {
         if (isEnabled()) {
             nagUserWith(deprecatedFeatureHandler, new DeprecatedFeatureUsage(summary, removalDetails, advice, contextualAdvice, DeprecatedFeatureUsage.Type.USER_CODE_DIRECT, SingleMessageLogger.class));
         }
@@ -295,12 +321,10 @@ public class SingleMessageLogger {
     }
 
     public static void nagUserOfDeprecatedThing(String thing) {
-        if (isEnabled()) {
-            nagUserWith(thing, String.format("This has been deprecated and %s", getRemovalDetails()), null, null, DeprecatedFeatureUsage.Type.USER_CODE_DIRECT);
-        }
+        nagUserOfDeprecatedThing(thing, null);
     }
 
-    public static void nagUserOfDeprecatedThing(String thing, String advice) {
+    public static void nagUserOfDeprecatedThing(String thing, @Nullable String advice) {
         if (isEnabled()) {
             nagUserWith(thing, String.format("This has been deprecated and %s", getRemovalDetails()), advice, null, DeprecatedFeatureUsage.Type.USER_CODE_DIRECT);
         }
@@ -329,6 +353,10 @@ public class SingleMessageLogger {
         return ENABLED.get();
     }
 
+    private static String thisWillBecomeAnError() {
+        return String.format("This will fail with an error in Gradle %s.", GradleVersion.current().getNextMajor().getVersion());
+    }
+
     private static String thisWillBeRemovedMessage() {
         return String.format("This %s", getRemovalDetails());
     }
