@@ -40,6 +40,7 @@ import org.gradle.api.internal.CompositeDomainObjectSet;
 import org.gradle.api.internal.FeaturePreviews;
 import org.gradle.api.internal.artifacts.DefaultExcludeRule;
 import org.gradle.api.internal.artifacts.DefaultModuleVersionIdentifier;
+import org.gradle.api.internal.artifacts.dsl.dependencies.PlatformSupport;
 import org.gradle.api.internal.artifacts.ivyservice.ivyresolve.parser.MavenVersionUtils;
 import org.gradle.api.internal.artifacts.ivyservice.projectmodule.ProjectDependencyPublicationResolver;
 import org.gradle.api.internal.attributes.ImmutableAttributes;
@@ -116,6 +117,7 @@ public class DefaultMavenPublication implements MavenPublicationInternal {
     private final Set<MavenDependencyInternal> apiDependencies = new LinkedHashSet<MavenDependencyInternal>();
     private final Set<MavenDependency> runtimeDependencyConstraints = new LinkedHashSet<MavenDependency>();
     private final Set<MavenDependency> apiDependencyConstraints = new LinkedHashSet<MavenDependency>();
+    private final Set<MavenDependency> importDependencyConstraints = new LinkedHashSet<MavenDependency>();
     private final ProjectDependencyPublicationResolver projectDependencyResolver;
     private final FeaturePreviews featurePreviews;
     private final ImmutableAttributesFactory immutableAttributesFactory;
@@ -251,20 +253,27 @@ public class DefaultMavenPublication implements MavenPublicationInternal {
                     if (dependency instanceof ProjectDependency) {
                         addProjectDependency((ProjectDependency) dependency, globalExcludes, dependencies);
                     } else {
-                        addModuleDependency(dependency, globalExcludes, dependencies);
+                        if (PlatformSupport.isTargettingPlatform(dependency)) {
+                            addImportDependencyConstraint(dependency);
+                        } else {
+                            addModuleDependency(dependency, globalExcludes, dependencies);
+                        }
                     }
                 }
             }
             Set<MavenDependency> dependencyConstraints = dependencyConstraintsFor(usageContext.getUsage());
             for (DependencyConstraint dependency : usageContext.getDependencyConstraints()) {
-                if (seenConstraints.add(dependency)
-                    && !dependency.getVersionConstraint().getPreferredVersion().isEmpty()) {
+                if (seenConstraints.add(dependency) && dependency.getVersion() != null) {
                     addDependencyConstraint(dependency, dependencyConstraints);
                 }
             }
         }
     }
 
+    private void addImportDependencyConstraint(ModuleDependency dependency) {
+        importDependencyConstraints.add(new DefaultMavenDependency(dependency.getGroup(), dependency.getName(), dependency.getVersion(), "pom"));
+    }
+
     private List<UsageContext> getSortedUsageContexts() {
         List<UsageContext> usageContexts = Lists.newArrayList(this.component.getUsages());
         Collections.sort(usageContexts, USAGE_ORDERING);
@@ -396,6 +405,12 @@ public class DefaultMavenPublication implements MavenPublicationInternal {
         return runtimeDependencyConstraints;
     }
 
+    @Override
+    public Set<MavenDependency> getImportDependencyConstraints() {
+        populateFromComponent();
+        return importDependencyConstraints;
+    }
+
     public Set<MavenDependencyInternal> getRuntimeDependencies() {
         populateFromComponent();
         return runtimeDependencies;
