@@ -23,18 +23,18 @@ import org.gradle.api.Task;
 import org.gradle.api.UnknownDomainObjectException;
 import org.gradle.api.internal.DefaultDomainObjectSet;
 import org.gradle.api.internal.TaskInternal;
-import org.gradle.api.internal.project.taskfactory.ITaskFactory;
+import org.gradle.model.internal.core.NamedEntityInstantiator;
 import org.gradle.platform.base.BinaryTasksCollection;
 
 public class DefaultBinaryTasksCollection extends DefaultDomainObjectSet<Task> implements BinaryTasksCollection {
 
     private final BinarySpecInternal binary;
-    private final ITaskFactory taskFactory;
+    private final NamedEntityInstantiator<Task> taskInstantiator;
 
-    public DefaultBinaryTasksCollection(BinarySpecInternal binarySpecInternal, ITaskFactory taskFactory) {
+    public DefaultBinaryTasksCollection(BinarySpecInternal binarySpecInternal, NamedEntityInstantiator<Task> taskInstantiator) {
         super(Task.class);
         this.binary = binarySpecInternal;
-        this.taskFactory = taskFactory;
+        this.taskInstantiator = taskInstantiator;
     }
 
     @Override
@@ -52,6 +52,11 @@ public class DefaultBinaryTasksCollection extends DefaultDomainObjectSet<Task> i
         return binary.getBuildTask();
     }
 
+    @Override
+    public Task getCheck() {
+        return binary.getCheckTask();
+    }
+
     public <T extends Task> T findSingleTaskWithType(Class<T> type) {
         DomainObjectSet<T> tasks = withType(type);
         if (tasks.size() == 0) {
@@ -65,7 +70,7 @@ public class DefaultBinaryTasksCollection extends DefaultDomainObjectSet<Task> i
 
     @Override
     public <T extends Task> void create(String name, Class<T> type, Action<? super T> config) {
-        @SuppressWarnings("unchecked") T task = (T) taskFactory.create(name, (Class<TaskInternal>) type);
+        @SuppressWarnings("unchecked") T task = (T) taskInstantiator.create(name, (Class<TaskInternal>) type);
         add(task);
         config.execute(task);
     }
