@@ -33,6 +33,8 @@ import org.gradle.api.tasks.Internal;
 import org.gradle.api.tasks.Nested;
 import org.gradle.api.tasks.OutputDirectory;
 import org.gradle.api.tasks.OutputFile;
+import org.gradle.api.tasks.PathSensitive;
+import org.gradle.api.tasks.PathSensitivity;
 import org.gradle.api.tasks.SkipWhenEmpty;
 import org.gradle.api.tasks.TaskAction;
 import org.gradle.api.tasks.WorkResult;
@@ -68,23 +70,23 @@ public abstract class AbstractLinkTask extends DefaultTask implements ObjectFile
     private final Property<NativeToolChain> toolChain;
 
     public AbstractLinkTask() {
-        ObjectFactory objectFactory = getProject().getObjects();
+        final ObjectFactory objectFactory = getProject().getObjects();
         this.libs = getProject().files();
         this.source = getProject().files();
-        this.linkedFile = newOutputFile();
-        this.destinationDirectory = newOutputDirectory();
+        this.linkedFile = objectFactory.fileProperty();
+        this.destinationDirectory = objectFactory.directoryProperty();
         destinationDirectory.set(linkedFile.map(new Transformer<Directory, RegularFile>() {
             @Override
             public Directory transform(RegularFile regularFile) {
                 // TODO: Get rid of destinationDirectory entirely and replace it with a
                 // collection of link outputs
-                DirectoryProperty dirProp = getProject().getLayout().directoryProperty();
+                DirectoryProperty dirProp = objectFactory.directoryProperty();
                 dirProp.set(regularFile.getAsFile().getParentFile());
                 return dirProp.get();
             }
         }));
-        this.linkerArgs = getProject().getObjects().listProperty(String.class);
-        this.debuggable = objectFactory.property(Boolean.class);
+        this.linkerArgs = getProject().getObjects().listProperty(String.class).empty();
+        this.debuggable = objectFactory.property(Boolean.class).value(false);
         this.targetPlatform = objectFactory.property(NativePlatform.class);
         this.toolChain = objectFactory.property(NativeToolChain.class);
     }
@@ -162,6 +164,7 @@ public abstract class AbstractLinkTask extends DefaultTask implements ObjectFile
     /**
      * The source object files to be passed to the linker.
      */
+    @PathSensitive(PathSensitivity.RELATIVE)
     @InputFiles
     @SkipWhenEmpty
     public ConfigurableFileCollection getSource() {
@@ -175,6 +178,7 @@ public abstract class AbstractLinkTask extends DefaultTask implements ObjectFile
     /**
      * The library files to be passed to the linker.
      */
+    @PathSensitive(PathSensitivity.RELATIVE)
     @InputFiles
     public ConfigurableFileCollection getLibs() {
         return libs;
