@@ -36,6 +36,9 @@ import org.gradle.api.tasks.Internal;
 import org.gradle.api.tasks.Nested;
 import org.gradle.api.tasks.Optional;
 import org.gradle.api.tasks.OutputDirectory;
+import org.gradle.api.tasks.OutputFile;
+import org.gradle.api.tasks.PathSensitive;
+import org.gradle.api.tasks.PathSensitivity;
 import org.gradle.api.tasks.SkipWhenEmpty;
 import org.gradle.api.tasks.TaskAction;
 import org.gradle.internal.nativeintegration.filesystem.FileSystem;
@@ -73,15 +76,17 @@ public class InstallExecutable extends DefaultTask {
         ObjectFactory objectFactory = getProject().getObjects();
         this.workerLeaseService = workerLeaseService;
         this.libs = getProject().files();
-        this.installDirectory = newOutputDirectory();
-        this.installedExecutable = newOutputFile();
+        this.installDirectory = objectFactory.directoryProperty();
+        this.installedExecutable = objectFactory.fileProperty();
         this.installedExecutable.set(getLibDirectory().map(new Transformer<RegularFile, Directory>() {
             @Override
             public RegularFile transform(Directory directory) {
                 return directory.file(executable.getAsFile().get().getName());
             }
         }));
-        this.executable = newInputFile();
+        this.executable = objectFactory.fileProperty();
+        // A further work around for missing ability to skip task when input file is missing (see #getInputFileIfExists below)
+        dependsOn(executable);
         this.targetPlatform = objectFactory.property(NativePlatform.class);
         this.toolChain = objectFactory.property(NativeToolChain.class);
     }
@@ -132,7 +137,7 @@ public class InstallExecutable extends DefaultTask {
      *
      * @since 4.7
      */
-    @Internal
+    @OutputFile
     public RegularFileProperty getInstalledExecutable() {
         return installedExecutable;
     }
@@ -142,9 +147,11 @@ public class InstallExecutable extends DefaultTask {
      *
      * @since 4.3
      */
+    // TODO - allow @InputFile and @SkipWhenEmpty to be attached to getExecutableFile()
     @SkipWhenEmpty
     @Nullable
     @Optional
+    @PathSensitive(PathSensitivity.NAME_ONLY)
     @InputFile
     protected File getInputFileIfExists() {
         RegularFileProperty sourceFile = getExecutableFile();
@@ -158,6 +165,7 @@ public class InstallExecutable extends DefaultTask {
     /**
      * The library files that should be installed.
      */
+    @PathSensitive(PathSensitivity.RELATIVE)
     @InputFiles
     public FileCollection getLibs() {
         return libs;
