@@ -16,20 +16,21 @@
 
 package org.gradle.api.reporting;
 
+import com.google.common.collect.Sets;
 import groovy.lang.Closure;
 import org.gradle.api.Action;
 import org.gradle.api.DefaultTask;
-import org.gradle.api.Incubating;
 import org.gradle.api.NamedDomainObjectSet;
+import org.gradle.api.Project;
+import org.gradle.api.Task;
 import org.gradle.api.Transformer;
-import org.gradle.api.internal.ClosureBackedAction;
 import org.gradle.api.reporting.internal.BuildDashboardGenerator;
 import org.gradle.api.reporting.internal.DefaultBuildDashboardReports;
 import org.gradle.api.tasks.Input;
-import org.gradle.api.tasks.Internal;
 import org.gradle.api.tasks.Nested;
 import org.gradle.api.tasks.TaskAction;
 import org.gradle.internal.reflect.Instantiator;
+import org.gradle.util.ClosureBackedAction;
 import org.gradle.util.CollectionUtils;
 
 import javax.inject.Inject;
@@ -43,9 +44,8 @@ import java.util.Set;
 /**
  * Generates build dashboard report.
  */
-@Incubating
 public class GenerateBuildDashboard extends DefaultTask implements Reporting<BuildDashboardReports> {
-    private Set<Reporting<? extends ReportContainer<?>>> aggregated = new LinkedHashSet<Reporting<? extends ReportContainer<?>>>();
+    private final Set<Reporting<? extends ReportContainer<?>>> aggregated = new LinkedHashSet<Reporting<? extends ReportContainer<?>>>();
 
     private final BuildDashboardReports reports;
 
@@ -61,7 +61,7 @@ public class GenerateBuildDashboard extends DefaultTask implements Reporting<Bui
 
     @Input
     public Set<ReportState> getInputReports() {
-        Set<ReportState> inputs = new HashSet<ReportState>();
+        Set<ReportState> inputs = new LinkedHashSet<ReportState>();
         for (Report report : getEnabledInputReports()) {
             if (getReports().contains(report)) {
                 // A report to be generated, ignore
@@ -72,9 +72,12 @@ public class GenerateBuildDashboard extends DefaultTask implements Reporting<Bui
         return inputs;
     }
 
-    @Internal
     private Set<Report> getEnabledInputReports() {
-        Set<NamedDomainObjectSet<? extends Report>> enabledReportSets = CollectionUtils.collect(aggregated, new Transformer<NamedDomainObjectSet<? extends Report>, Reporting<? extends ReportContainer<?>>>() {
+        HashSet<Reporting<? extends ReportContainer<?>>> allAggregatedReports = Sets.newHashSet(aggregated);
+        allAggregatedReports.addAll(getAggregatedTasks());
+
+        Set<NamedDomainObjectSet<? extends Report>> enabledReportSets = CollectionUtils.collect(allAggregatedReports,
+            new Transformer<NamedDomainObjectSet<? extends Report>, Reporting<? extends ReportContainer<?>>>() {
             public NamedDomainObjectSet<? extends Report> transform(Reporting<? extends ReportContainer<?>> reporting) {
                 return reporting.getReports().getEnabled();
             }
@@ -82,6 +85,25 @@ public class GenerateBuildDashboard extends DefaultTask implements Reporting<Bui
         return new LinkedHashSet<Report>(CollectionUtils.flattenCollections(Report.class, enabledReportSets));
     }
 
+    private Set<Reporting<? extends ReportContainer<?>>> getAggregatedTasks() {
+        final Set<Reporting<? extends ReportContainer<?>>> reports = Sets.newHashSet();
+        getProject().allprojects(new Action<Project>() {
+            @Override
+            public void execute(Project project) {
+                project.getTasks().all(new Action<Task>() {
+                    @Override
+                    public void execute(Task task) {
+                        if (!(task instanceof Reporting)) {
+                            return;
+                        }
+                        reports.add((Reporting) task);
+                    }
+                });
+            }
+        });
+        return reports;
+    }
+
     /**
      * Configures which reports are to be aggregated in the build dashboard report generated by this task.
      *
