@@ -21,13 +21,10 @@ import org.gradle.api.Incubating;
 import org.gradle.api.NamedDomainObjectSet;
 import org.gradle.api.Namer;
 import org.gradle.api.Rule;
-import org.gradle.api.tasks.Input;
 import org.gradle.api.tasks.Internal;
-import org.gradle.api.tasks.OutputDirectories;
-import org.gradle.api.tasks.OutputFiles;
+import org.gradle.api.tasks.Nested;
 import org.gradle.util.Configurable;
 
-import java.io.File;
 import java.util.List;
 import java.util.Map;
 import java.util.SortedMap;
@@ -91,15 +88,12 @@ public interface ReportContainer<T extends Report> extends NamedDomainObjectSet<
     @Internal
     boolean isEmpty();
 
+    /**
+     * Returns the enabled reports, keyed by report name.
+     *
+     * @since 4.7
+     */
     @Incubating
-    @OutputDirectories
-    Map<String, File> getEnabledDirectoryReportDestinations();
-
-    @Incubating
-    @OutputFiles
-    Map<String, File> getEnabledFileReportDestinations();
-
-    @Incubating
-    @Input
-    SortedSet<String> getEnabledReportNames();
+    @Nested
+    Map<String, T> getEnabledReports();
 }
