@@ -17,12 +17,11 @@
 package org.gradle.workers.internal;
 
 import org.gradle.internal.operations.BuildOperationRef;
-import org.gradle.internal.work.WorkerLeaseRegistry.WorkerLease;
 
 /**
  * A service that executes work in a (potentially) long-lived process or in-process.
  */
 public interface Worker {
     DefaultWorkResult execute(ActionExecutionSpec spec);
-    DefaultWorkResult execute(ActionExecutionSpec spec, WorkerLease parentWorkerWorkerLease, final BuildOperationRef parentBuildOperation);
+    DefaultWorkResult execute(ActionExecutionSpec spec, final BuildOperationRef parentBuildOperation);
 }
